-----------------------------------------------------------------------
-- Upvalued Lua API.
-----------------------------------------------------------------------
local _G = getfenv(0)
local select = _G.select
local string = _G.string
local format = string.format

-- WoW

-- ----------------------------------------------------------------------------
-- AddOn namespace.
-- ----------------------------------------------------------------------------
local addonname = ...
local AtlasLoot = _G.AtlasLoot
if AtlasLoot:GetGameVersion() < 2 then return end

--##START-DATA##
local SOURCE_DATA = {
	["AtlasLootIDs"] = {
		"HellfireRamparts",
		"TheBloodFurnace",
		"TheShatteredHalls",
		"Mana-Tombs",
		"AuchenaiCrypts",
		"SethekkHalls",
		"ShadowLabyrinth",
		"TheSlavePens",
		"TheUnderbog",
		"TheSteamvault",
		"OldHillsbradFoothills",
		"TheBlackMorass",
		"TheArcatraz",
		"TheBotanica",
		"TheMechanar",
		"MagistersTerrace",
		"Karazhan",
		"ZulAman",
		"WorldBossesBC",
		"MagtheridonsLair",
		"GruulsLair",
		"SerpentshrineCavern",
		"TempestKeep",
		"HyjalSummit",
		"BlackTemple",
		"SunwellPlateau"
	},
	["ItemData"] = {
		[118] = {[3] = 7,[4] = 2330},
		[724] = {[3] = 9,[4] = 2542},
		[733] = {[3] = 9,[4] = 2543},
		[787] = {[3] = 9,[4] = 7752},
		[858] = {[3] = 7,[4] = 2337},
		[929] = {[3] = 7,[4] = 3447},
		[1017] = {[3] = 9,[4] = 2549},
		[1082] = {[3] = 9,[4] = 2547},
		[1251] = {[3] = 4,[4] = 3275},
		[1710] = {[3] = 7,[4] = 7181},
		[2300] = {[3] = 6,[4] = 2160},
		[2302] = {[3] = 6,[4] = 2149},
		[2303] = {[3] = 6,[4] = 2153},
		[2304] = {[3] = 6,[4] = 2152},
		[2305] = {[3] = 6,[4] = 2156},
		[2306] = {[3] = 6,[4] = 2157},
		[2307] = {[3] = 6,[4] = 2158},
		[2308] = {[3] = 6,[4] = 2159},
		[2309] = {[3] = 6,[4] = 2161},
		[2310] = {[3] = 6,[4] = 2162},
		[2311] = {[3] = 6,[4] = 2163},
		[2312] = {[3] = 6,[4] = 2164},
		[2313] = {[3] = 6,[4] = 2165},
		[2314] = {[3] = 6,[4] = 2166},
		[2315] = {[3] = 6,[4] = 2167},
		[2316] = {[3] = 6,[4] = 2168},
		[2317] = {[3] = 6,[4] = 2169},
		[2318] = {[3] = 6,[4] = 2881},
		[2319] = {[3] = 6,[4] = 20648},
		[2454] = {[3] = 7,[4] = 2329},
		[2455] = {[3] = 7,[4] = 2331},
		[2456] = {[3] = 7,[4] = 2332},
		[2457] = {[3] = 7,[4] = 3230},
		[2458] = {[3] = 7,[4] = 2334},
		[2459] = {[3] = 7,[4] = 2335},
		[2460] = {[3] = 7,[4] = 2336},
		[2568] = {[3] = 11,[4] = 2385},
		[2569] = {[3] = 11,[4] = 2386},
		[2570] = {[3] = 11,[4] = 2387},
		[2572] = {[3] = 11,[4] = 2389},
		[2575] = {[3] = 11,[4] = 2392},
		[2576] = {[3] = 11,[4] = 2393},
		[2577] = {[3] = 11,[4] = 2394},
		[2578] = {[3] = 11,[4] = 2395},
		[2579] = {[3] = 11,[4] = 2396},
		[2580] = {[3] = 11,[4] = 2397},
		[2581] = {[3] = 4,[4] = 3276},
		[2582] = {[3] = 11,[4] = 2399},
		[2583] = {[3] = 11,[4] = 2401},
		[2584] = {[3] = 11,[4] = 2402},
		[2585] = {[3] = 11,[4] = 2403},
		[2587] = {[3] = 11,[4] = 2406},
		[2679] = {[3] = 9,[4] = 2538},
		[2680] = {[3] = 9,[4] = 2539},
		[2681] = {[3] = 9,[4] = 2540},
		[2682] = {[3] = 9,[4] = 2545},
		[2683] = {[3] = 9,[4] = 2544},
		[2684] = {[3] = 9,[4] = 2541},
		[2685] = {[3] = 9,[4] = 2548},
		[2687] = {[3] = 9,[4] = 2546},
		[2840] = {[3] = 10,[4] = 2657},
		[2841] = {[3] = 10,[4] = 2659},
		[2842] = {[3] = 10,[4] = 2658},
		[2844] = {[3] = 5,[4] = 2737},
		[2845] = {[3] = 5,[4] = 2738},
		[2847] = {[3] = 5,[4] = 2739},
		[2848] = {[3] = 5,[4] = 2740},
		[2849] = {[3] = 5,[4] = 2741},
		[2850] = {[3] = 5,[4] = 2742},
		[2851] = {[3] = 5,[4] = 2661},
		[2852] = {[3] = 5,[4] = 2662},
		[2853] = {[3] = 5,[4] = 2663},
		[2854] = {[3] = 5,[4] = 2664},
		[2857] = {[3] = 5,[4] = 2666},
		[2862] = {[3] = 5,[4] = 2660},
		[2863] = {[3] = 5,[4] = 2665},
		[2864] = {[3] = 5,[4] = 2667},
		[2865] = {[3] = 5,[4] = 2668},
		[2866] = {[3] = 5,[4] = 2670},
		[2867] = {[3] = 5,[4] = 2671},
		[2868] = {[3] = 5,[4] = 2672},
		[2869] = {[3] = 5,[4] = 2673},
		[2870] = {[3] = 5,[4] = 2675},
		[2871] = {[3] = 5,[4] = 2674},
		[2888] = {[3] = 9,[4] = 2795},
		[2892] = {[3] = 16,[4] = 2835},
		[2893] = {[3] = 16,[4] = 2837},
		[2996] = {[3] = 11,[4] = 2963},
		[2997] = {[3] = 11,[4] = 2964},
		[3220] = {[3] = 9,[4] = 3371},
		[3239] = {[3] = 5,[4] = 3115},
		[3240] = {[3] = 5,[4] = 3116},
		[3241] = {[3] = 5,[4] = 3117},
		[3382] = {[3] = 7,[4] = 3170},
		[3383] = {[3] = 7,[4] = 3171},
		[3384] = {[3] = 7,[4] = 3172},
		[3385] = {[3] = 7,[4] = 3173},
		[3386] = {[3] = 7,[4] = 3174},
		[3387] = {[3] = 7,[4] = 3175},
		[3388] = {[3] = 7,[4] = 3176},
		[3389] = {[3] = 7,[4] = 3177},
		[3390] = {[3] = 7,[4] = 2333},
		[3391] = {[3] = 7,[4] = 3188},
		[3469] = {[3] = 5,[4] = 3319},
		[3470] = {[3] = 5,[4] = 3320},
		[3471] = {[3] = 5,[4] = 3321},
		[3472] = {[3] = 5,[4] = 3323},
		[3473] = {[3] = 5,[4] = 3324},
		[3474] = {[3] = 5,[4] = 3325},
		[3478] = {[3] = 5,[4] = 3326},
		[3480] = {[3] = 5,[4] = 3328},
		[3481] = {[3] = 5,[4] = 3330},
		[3482] = {[3] = 5,[4] = 3331},
		[3483] = {[3] = 5,[4] = 3333},
		[3484] = {[3] = 5,[4] = 3334},
		[3485] = {[3] = 5,[4] = 3336},
		[3486] = {[3] = 5,[4] = 3337},
		[3487] = {[3] = 5,[4] = 3292},
		[3488] = {[3] = 5,[4] = 3293},
		[3489] = {[3] = 5,[4] = 3294},
		[3490] = {[3] = 5,[4] = 3295},
		[3491] = {[3] = 5,[4] = 3296},
		[3492] = {[3] = 5,[4] = 3297},
		[3530] = {[3] = 4,[4] = 3277},
		[3531] = {[3] = 4,[4] = 3278},
		[3575] = {[3] = 10,[4] = 3307},
		[3576] = {[3] = 10,[4] = 3304},
		[3577] = {[3] = 7,[4] = 11479},
		[3662] = {[3] = 9,[4] = 3370},
		[3663] = {[3] = 9,[4] = 3372},
		[3664] = {[3] = 9,[4] = 3373},
		[3665] = {[3] = 9,[4] = 3376},
		[3666] = {[3] = 9,[4] = 3377},
		[3719] = {[3] = 6,[4] = 3760},
		[3726] = {[3] = 9,[4] = 3397},
		[3727] = {[3] = 9,[4] = 3398},
		[3728] = {[3] = 9,[4] = 3399},
		[3729] = {[3] = 9,[4] = 3400},
		[3775] = {[3] = 16,[4] = 3420},
		[3776] = {[3] = 16,[4] = 3421},
		[3823] = {[3] = 7,[4] = 3448},
		[3824] = {[3] = 7,[4] = 3449},
		[3825] = {[3] = 7,[4] = 3450},
		[3826] = {[3] = 7,[4] = 3451},
		[3827] = {[3] = 7,[4] = 3452},
		[3828] = {[3] = 7,[4] = 3453},
		[3829] = {[3] = 7,[4] = 3454},
		[3835] = {[3] = 5,[4] = 3501},
		[3836] = {[3] = 5,[4] = 3502},
		[3837] = {[3] = 5,[4] = 3503},
		[3840] = {[3] = 5,[4] = 3504},
		[3841] = {[3] = 5,[4] = 3505},
		[3842] = {[3] = 5,[4] = 3506},
		[3843] = {[3] = 5,[4] = 3507},
		[3844] = {[3] = 5,[4] = 3508},
		[3845] = {[3] = 5,[4] = 3511},
		[3846] = {[3] = 5,[4] = 3513},
		[3847] = {[3] = 5,[4] = 3515},
		[3848] = {[3] = 5,[4] = 3491},
		[3849] = {[3] = 5,[4] = 3492},
		[3850] = {[3] = 5,[4] = 3493},
		[3851] = {[3] = 5,[4] = 3494},
		[3852] = {[3] = 5,[4] = 3495},
		[3853] = {[3] = 5,[4] = 3496},
		[3854] = {[3] = 5,[4] = 3497},
		[3855] = {[3] = 5,[4] = 3498},
		[3856] = {[3] = 5,[4] = 3500},
		[3859] = {[3] = 10,[4] = 3569},
		[3860] = {[3] = 10,[4] = 10097},
		[3928] = {[3] = 7,[4] = 11457},
		[4231] = {[3] = 6,[4] = 3816},
		[4233] = {[3] = 6,[4] = 3817},
		[4234] = {[3] = 6,[4] = 20649},
		[4236] = {[3] = 6,[4] = 3818},
		[4237] = {[3] = 6,[4] = 3753},
		[4238] = {[3] = 11,[4] = 3755},
		[4239] = {[3] = 6,[4] = 3756},
		[4240] = {[3] = 11,[4] = 3757},
		[4241] = {[3] = 11,[4] = 3758},
		[4242] = {[3] = 6,[4] = 3759},
		[4243] = {[3] = 6,[4] = 3761},
		[4244] = {[3] = 6,[4] = 3762},
		[4245] = {[3] = 11,[4] = 3813},
		[4246] = {[3] = 6,[4] = 3763},
		[4247] = {[3] = 6,[4] = 3764},
		[4248] = {[3] = 6,[4] = 3765},
		[4249] = {[3] = 6,[4] = 3766},
		[4250] = {[3] = 6,[4] = 3767},
		[4251] = {[3] = 6,[4] = 3768},
		[4252] = {[3] = 6,[4] = 3769},
		[4253] = {[3] = 6,[4] = 3770},
		[4254] = {[3] = 6,[4] = 3771},
		[4255] = {[3] = 6,[4] = 3772},
		[4256] = {[3] = 6,[4] = 3773},
		[4257] = {[3] = 6,[4] = 3774},
		[4258] = {[3] = 6,[4] = 3775},
		[4259] = {[3] = 6,[4] = 3776},
		[4260] = {[3] = 6,[4] = 3777},
		[4262] = {[3] = 6,[4] = 3778},
		[4264] = {[3] = 6,[4] = 3779},
		[4265] = {[3] = 6,[4] = 3780},
		[4304] = {[3] = 6,[4] = 20650},
		[4305] = {[3] = 11,[4] = 3839},
		[4307] = {[3] = 11,[4] = 3840},
		[4308] = {[3] = 11,[4] = 3841},
		[4309] = {[3] = 11,[4] = 3842},
		[4310] = {[3] = 11,[4] = 3843},
		[4311] = {[3] = 11,[4] = 3844},
		[4312] = {[3] = 11,[4] = 3845},
		[4313] = {[3] = 11,[4] = 3847},
		[4314] = {[3] = 11,[4] = 3848},
		[4315] = {[3] = 11,[4] = 3849},
		[4316] = {[3] = 11,[4] = 3850},
		[4317] = {[3] = 11,[4] = 3851},
		[4318] = {[3] = 11,[4] = 3852},
		[4319] = {[3] = 11,[4] = 3854},
		[4320] = {[3] = 11,[4] = 3855},
		[4321] = {[3] = 11,[4] = 3856},
		[4322] = {[3] = 11,[4] = 3857},
		[4323] = {[3] = 11,[4] = 3858},
		[4324] = {[3] = 11,[4] = 3859},
		[4325] = {[3] = 11,[4] = 3860},
		[4326] = {[3] = 11,[4] = 3861},
		[4327] = {[3] = 11,[4] = 3862},
		[4328] = {[3] = 11,[4] = 3863},
		[4329] = {[3] = 11,[4] = 3864},
		[4330] = {[3] = 11,[4] = 3866},
		[4331] = {[3] = 11,[4] = 3868},
		[4332] = {[3] = 11,[4] = 3869},
		[4333] = {[3] = 11,[4] = 3870},
		[4334] = {[3] = 11,[4] = 3871},
		[4335] = {[3] = 11,[4] = 3872},
		[4336] = {[3] = 11,[4] = 3873},
		[4339] = {[3] = 11,[4] = 3865},
		[4343] = {[3] = 11,[4] = 3914},
		[4344] = {[3] = 11,[4] = 3915},
		[4357] = {[3] = 12,[4] = 3918},
		[4358] = {[3] = 12,[4] = 3919},
		[4359] = {[3] = 12,[4] = 3922},
		[4360] = {[3] = 12,[4] = 3923},
		[4361] = {[3] = 12,[4] = 3924},
		[4362] = {[3] = 12,[4] = 3925},
		[4363] = {[3] = 12,[4] = 3926},
		[4364] = {[3] = 12,[4] = 3929},
		[4365] = {[3] = 12,[4] = 3931},
		[4366] = {[3] = 12,[4] = 3932},
		[4367] = {[3] = 12,[4] = 3933},
		[4368] = {[3] = 12,[4] = 3934},
		[4369] = {[3] = 12,[4] = 3936},
		[4370] = {[3] = 12,[4] = 3937},
		[4371] = {[3] = 12,[4] = 3938},
		[4372] = {[3] = 12,[4] = 3939},
		[4373] = {[3] = 12,[4] = 3940},
		[4374] = {[3] = 12,[4] = 3941},
		[4375] = {[3] = 12,[4] = 3942},
		[4376] = {[3] = 12,[4] = 3944},
		[4377] = {[3] = 12,[4] = 3945},
		[4378] = {[3] = 12,[4] = 3946},
		[4379] = {[3] = 12,[4] = 3949},
		[4380] = {[3] = 12,[4] = 3950},
		[4381] = {[3] = 12,[4] = 3952},
		[4382] = {[3] = 12,[4] = 3953},
		[4383] = {[3] = 12,[4] = 3954},
		[4384] = {[3] = 12,[4] = 3955},
		[4385] = {[3] = 12,[4] = 3956},
		[4386] = {[3] = 12,[4] = 3957},
		[4387] = {[3] = 12,[4] = 3958},
		[4388] = {[3] = 12,[4] = 3959},
		[4389] = {[3] = 12,[4] = 3961},
		[4390] = {[3] = 12,[4] = 3962},
		[4391] = {[3] = 12,[4] = 3963},
		[4392] = {[3] = 12,[4] = 3965},
		[4393] = {[3] = 12,[4] = 3966},
		[4394] = {[3] = 12,[4] = 3967},
		[4395] = {[3] = 12,[4] = 3968},
		[4396] = {[3] = 12,[4] = 3969},
		[4397] = {[3] = 12,[4] = 3971},
		[4398] = {[3] = 12,[4] = 3972},
		[4401] = {[3] = 12,[4] = 3928},
		[4403] = {[3] = 12,[4] = 3960},
		[4404] = {[3] = 12,[4] = 3973},
		[4405] = {[3] = 12,[4] = 3977},
		[4406] = {[3] = 12,[4] = 3978},
		[4407] = {[3] = 12,[4] = 3979},
		[4455] = {[3] = 6,[4] = 4096},
		[4456] = {[3] = 6,[4] = 4097},
		[4457] = {[3] = 9,[4] = 4094},
		[4592] = {[3] = 9,[4] = 7753},
		[4593] = {[3] = 9,[4] = 7755},
		[4594] = {[3] = 9,[4] = 7828},
		[4596] = {[3] = 7,[4] = 4508},
		[4623] = {[3] = 7,[4] = 4942},
		[4852] = {[3] = 12,[4] = 8243},
		[5081] = {[3] = 6,[4] = 5244},
		[5095] = {[3] = 9,[4] = 7827},
		[5237] = {[3] = 16,[4] = 5763},
		[5472] = {[3] = 9,[4] = 6412},
		[5473] = {[3] = 9,[4] = 6413},
		[5474] = {[3] = 9,[4] = 6414},
		[5476] = {[3] = 9,[4] = 6415},
		[5477] = {[3] = 9,[4] = 6416},
		[5478] = {[3] = 9,[4] = 6417},
		[5479] = {[3] = 9,[4] = 6418},
		[5480] = {[3] = 9,[4] = 6419},
		[5507] = {[3] = 12,[4] = 6458},
		[5525] = {[3] = 9,[4] = 6499},
		[5526] = {[3] = 9,[4] = 6501},
		[5527] = {[3] = 9,[4] = 6500},
		[5540] = {[3] = 5,[4] = 6517},
		[5541] = {[3] = 5,[4] = 6518},
		[5542] = {[3] = 11,[4] = 6521},
		[5631] = {[3] = 7,[4] = 6617},
		[5632] = {[3] = 7,[4] = 6619},
		[5633] = {[3] = 7,[4] = 6618},
		[5634] = {[3] = 7,[4] = 6624},
		[5739] = {[3] = 6,[4] = 6661},
		[5762] = {[3] = 11,[4] = 6686},
		[5763] = {[3] = 11,[4] = 6688},
		[5764] = {[3] = 11,[4] = 6693},
		[5765] = {[3] = 11,[4] = 6695},
		[5766] = {[3] = 11,[4] = 6690},
		[5770] = {[3] = 11,[4] = 6692},
		[5780] = {[3] = 6,[4] = 6702},
		[5781] = {[3] = 6,[4] = 6703},
		[5782] = {[3] = 6,[4] = 6704},
		[5783] = {[3] = 6,[4] = 6705},
		[5957] = {[3] = 6,[4] = 7126},
		[5958] = {[3] = 6,[4] = 7133},
		[5961] = {[3] = 6,[4] = 7135},
		[5962] = {[3] = 6,[4] = 7147},
		[5963] = {[3] = 6,[4] = 7149},
		[5964] = {[3] = 6,[4] = 7151},
		[5965] = {[3] = 6,[4] = 7153},
		[5966] = {[3] = 6,[4] = 7156},
		[5996] = {[3] = 7,[4] = 7179},
		[5997] = {[3] = 7,[4] = 7183},
		[6037] = {[3] = 7,[4] = 11480},
		[6038] = {[3] = 9,[4] = 7213},
		[6040] = {[3] = 5,[4] = 7223},
		[6041] = {[3] = 5,[4] = 7224},
		[6042] = {[3] = 5,[4] = 7221},
		[6043] = {[3] = 5,[4] = 7222},
		[6048] = {[3] = 7,[4] = 7256},
		[6049] = {[3] = 7,[4] = 7257},
		[6050] = {[3] = 7,[4] = 7258},
		[6051] = {[3] = 7,[4] = 7255},
		[6052] = {[3] = 7,[4] = 7259},
		[6149] = {[3] = 7,[4] = 11448},
		[6214] = {[3] = 5,[4] = 7408},
		[6218] = {[3] = 13,[4] = 7421},
		[6219] = {[3] = 12,[4] = 7430},
		[6238] = {[3] = 11,[4] = 7623},
		[6239] = {[3] = 11,[4] = 7629},
		[6240] = {[3] = 11,[4] = 7630},
		[6241] = {[3] = 11,[4] = 7624},
		[6242] = {[3] = 11,[4] = 7633},
		[6243] = {[3] = 11,[4] = 7636},
		[6263] = {[3] = 11,[4] = 7639},
		[6264] = {[3] = 11,[4] = 7643},
		[6290] = {[3] = 9,[4] = 7751},
		[6316] = {[3] = 9,[4] = 7754},
		[6338] = {[3] = 5,[4] = 7818},
		[6339] = {[3] = 13,[4] = 7795},
		[6350] = {[3] = 5,[4] = 7817},
		[6370] = {[3] = 7,[4] = 7836},
		[6371] = {[3] = 7,[4] = 7837},
		[6372] = {[3] = 7,[4] = 7841},
		[6373] = {[3] = 7,[4] = 7845},
		[6384] = {[3] = 11,[4] = 7892},
		[6385] = {[3] = 11,[4] = 7893},
		[6450] = {[3] = 4,[4] = 7928},
		[6451] = {[3] = 4,[4] = 7929},
		[6452] = {[3] = 4,[4] = 7934},
		[6453] = {[3] = 4,[4] = 7935},
		[6466] = {[3] = 6,[4] = 7953},
		[6467] = {[3] = 6,[4] = 7954},
		[6468] = {[3] = 6,[4] = 7955},
		[6533] = {[3] = 12,[4] = 9271},
		[6657] = {[3] = 9,[4] = 8238},
		[6662] = {[3] = 7,[4] = 8240},
		[6709] = {[3] = 6,[4] = 8322},
		[6712] = {[3] = 12,[4] = 8334},
		[6714] = {[3] = 12,[4] = 8339},
		[6730] = {[3] = 5,[4] = 8366},
		[6731] = {[3] = 5,[4] = 8367},
		[6733] = {[3] = 5,[4] = 8368},
		[6786] = {[3] = 11,[4] = 8465},
		[6787] = {[3] = 11,[4] = 8467},
		[6795] = {[3] = 11,[4] = 8483},
		[6796] = {[3] = 11,[4] = 8489},
		[6836] = {[3] = 11,[4] = 49677},
		[6887] = {[3] = 9,[4] = 18238},
		[6888] = {[3] = 9,[4] = 8604},
		[6890] = {[3] = 9,[4] = 8607},
		[6947] = {[3] = 16,[4] = 8681},
		[6949] = {[3] = 16,[4] = 8687},
		[6950] = {[3] = 16,[4] = 8691},
		[6951] = {[3] = 16,[4] = 8694},
		[7026] = {[3] = 11,[4] = 8776},
		[7027] = {[3] = 11,[4] = 8778},
		[7046] = {[3] = 11,[4] = 8758},
		[7047] = {[3] = 11,[4] = 8780},
		[7048] = {[3] = 11,[4] = 8760},
		[7049] = {[3] = 11,[4] = 8782},
		[7050] = {[3] = 11,[4] = 8762},
		[7051] = {[3] = 11,[4] = 8764},
		[7052] = {[3] = 11,[4] = 8766},
		[7053] = {[3] = 11,[4] = 8786},
		[7054] = {[3] = 11,[4] = 8770},
		[7055] = {[3] = 11,[4] = 8772},
		[7056] = {[3] = 11,[4] = 8789},
		[7057] = {[3] = 11,[4] = 8774},
		[7058] = {[3] = 11,[4] = 8791},
		[7059] = {[3] = 11,[4] = 8793},
		[7060] = {[3] = 11,[4] = 8795},
		[7061] = {[3] = 11,[4] = 8797},
		[7062] = {[3] = 11,[4] = 8799},
		[7063] = {[3] = 11,[4] = 8802},
		[7064] = {[3] = 11,[4] = 8804},
		[7065] = {[3] = 11,[4] = 8784},
		[7068] = {[3] = 7,[4] = 25146},
		[7071] = {[3] = 5,[4] = 8768},
		[7076] = {[3] = 7,[4] = 17560},
		[7078] = {[3] = 7,[4] = 17559},
		[7080] = {[3] = 7,[4] = 17563},
		[7082] = {[3] = 7,[4] = 17562},
		[7148] = {[3] = 12,[4] = 9273},
		[7166] = {[3] = 5,[4] = 8880},
		[7189] = {[3] = 12,[4] = 8895},
		[7191] = {[3] = 12,[4] = 39895},
		[7276] = {[3] = 6,[4] = 9058},
		[7277] = {[3] = 6,[4] = 9059},
		[7278] = {[3] = 6,[4] = 9060},
		[7279] = {[3] = 6,[4] = 9062},
		[7280] = {[3] = 6,[4] = 9064},
		[7281] = {[3] = 6,[4] = 9065},
		[7282] = {[3] = 6,[4] = 9068},
		[7283] = {[3] = 6,[4] = 9070},
		[7284] = {[3] = 6,[4] = 9072},
		[7285] = {[3] = 6,[4] = 9074},
		[7348] = {[3] = 6,[4] = 9145},
		[7349] = {[3] = 6,[4] = 9146},
		[7352] = {[3] = 6,[4] = 9147},
		[7358] = {[3] = 6,[4] = 9148},
		[7359] = {[3] = 6,[4] = 9149},
		[7371] = {[3] = 6,[4] = 9193},
		[7372] = {[3] = 6,[4] = 9194},
		[7373] = {[3] = 6,[4] = 9195},
		[7374] = {[3] = 6,[4] = 9196},
		[7375] = {[3] = 6,[4] = 9197},
		[7377] = {[3] = 6,[4] = 9198},
		[7378] = {[3] = 6,[4] = 9201},
		[7386] = {[3] = 6,[4] = 9202},
		[7387] = {[3] = 6,[4] = 9206},
		[7390] = {[3] = 6,[4] = 9207},
		[7391] = {[3] = 6,[4] = 9208},
		[7506] = {[3] = 12,[4] = 9269},
		[7676] = {[3] = 9,[4] = 9513},
		[7913] = {[3] = 5,[4] = 9811},
		[7914] = {[3] = 5,[4] = 9813},
		[7915] = {[3] = 5,[4] = 9814},
		[7916] = {[3] = 5,[4] = 9818},
		[7917] = {[3] = 5,[4] = 9820},
		[7918] = {[3] = 5,[4] = 9926},
		[7919] = {[3] = 5,[4] = 9928},
		[7920] = {[3] = 5,[4] = 9931},
		[7921] = {[3] = 5,[4] = 9933},
		[7922] = {[3] = 5,[4] = 9935},
		[7924] = {[3] = 5,[4] = 9937},
		[7925] = {[3] = 5,[4] = 9942},
		[7926] = {[3] = 5,[4] = 9945},
		[7927] = {[3] = 5,[4] = 9950},
		[7928] = {[3] = 5,[4] = 9952},
		[7929] = {[3] = 5,[4] = 9957},
		[7930] = {[3] = 5,[4] = 9959},
		[7931] = {[3] = 5,[4] = 9961},
		[7932] = {[3] = 5,[4] = 9966},
		[7933] = {[3] = 5,[4] = 9968},
		[7934] = {[3] = 5,[4] = 9970},
		[7935] = {[3] = 5,[4] = 9972},
		[7936] = {[3] = 5,[4] = 9979},
		[7937] = {[3] = 5,[4] = 9980},
		[7938] = {[3] = 5,[4] = 9954},
		[7939] = {[3] = 5,[4] = 9974},
		[7941] = {[3] = 5,[4] = 9993},
		[7942] = {[3] = 5,[4] = 9995},
		[7943] = {[3] = 5,[4] = 9997},
		[7944] = {[3] = 5,[4] = 10005},
		[7945] = {[3] = 5,[4] = 10001},
		[7946] = {[3] = 5,[4] = 10009},
		[7947] = {[3] = 5,[4] = 10013},
		[7954] = {[3] = 5,[4] = 10003},
		[7955] = {[3] = 5,[4] = 9983},
		[7956] = {[3] = 5,[4] = 9985},
		[7957] = {[3] = 5,[4] = 9986},
		[7958] = {[3] = 5,[4] = 9987},
		[7959] = {[3] = 5,[4] = 10011},
		[7960] = {[3] = 5,[4] = 10015},
		[7961] = {[3] = 5,[4] = 10007},
		[7963] = {[3] = 5,[4] = 9916},
		[7964] = {[3] = 5,[4] = 9918},
		[7965] = {[3] = 5,[4] = 9921},
		[7966] = {[3] = 5,[4] = 9920},
		[7967] = {[3] = 5,[4] = 9939},
		[7969] = {[3] = 5,[4] = 9964},
		[8067] = {[3] = 12,[4] = 3920},
		[8068] = {[3] = 12,[4] = 3930},
		[8069] = {[3] = 12,[4] = 3947},
		[8170] = {[3] = 6,[4] = 22331},
		[8172] = {[3] = 6,[4] = 10482},
		[8173] = {[3] = 6,[4] = 10487},
		[8174] = {[3] = 6,[4] = 10490},
		[8175] = {[3] = 6,[4] = 10499},
		[8176] = {[3] = 6,[4] = 10507},
		[8185] = {[3] = 6,[4] = 10556},
		[8187] = {[3] = 6,[4] = 10509},
		[8189] = {[3] = 6,[4] = 10511},
		[8191] = {[3] = 6,[4] = 10552},
		[8192] = {[3] = 6,[4] = 10516},
		[8193] = {[3] = 6,[4] = 10548},
		[8195] = {[3] = 6,[4] = 10550},
		[8197] = {[3] = 6,[4] = 10558},
		[8198] = {[3] = 6,[4] = 10518},
		[8200] = {[3] = 6,[4] = 10520},
		[8201] = {[3] = 6,[4] = 10531},
		[8202] = {[3] = 6,[4] = 10560},
		[8203] = {[3] = 6,[4] = 10525},
		[8204] = {[3] = 6,[4] = 10542},
		[8205] = {[3] = 6,[4] = 10533},
		[8206] = {[3] = 6,[4] = 10568},
		[8207] = {[3] = 6,[4] = 10564},
		[8208] = {[3] = 6,[4] = 10570},
		[8209] = {[3] = 6,[4] = 10554},
		[8210] = {[3] = 6,[4] = 10529},
		[8211] = {[3] = 6,[4] = 10544},
		[8212] = {[3] = 6,[4] = 10572},
		[8213] = {[3] = 6,[4] = 10566},
		[8214] = {[3] = 6,[4] = 10546},
		[8215] = {[3] = 6,[4] = 10574},
		[8216] = {[3] = 6,[4] = 10562},
		[8217] = {[3] = 6,[4] = 14930},
		[8218] = {[3] = 6,[4] = 14932},
		[8345] = {[3] = 6,[4] = 10621},
		[8346] = {[3] = 6,[4] = 10630},
		[8347] = {[3] = 6,[4] = 10619},
		[8348] = {[3] = 6,[4] = 10632},
		[8349] = {[3] = 6,[4] = 10647},
		[8364] = {[3] = 9,[4] = 20916},
		[8367] = {[3] = 6,[4] = 10650},
		[8544] = {[3] = 4,[4] = 10840},
		[8545] = {[3] = 4,[4] = 10841},
		[8546] = {[3] = 4,[4] = 10844},
		[8827] = {[3] = 7,[4] = 11447},
		[8926] = {[3] = 16,[4] = 11341},
		[8927] = {[3] = 16,[4] = 11342},
		[8928] = {[3] = 16,[4] = 11343},
		[8949] = {[3] = 7,[4] = 11449},
		[8951] = {[3] = 7,[4] = 11450},
		[8956] = {[3] = 7,[4] = 11451},
		[8984] = {[3] = 16,[4] = 11357},
		[8985] = {[3] = 16,[4] = 11358},
		[9030] = {[3] = 7,[4] = 11452},
		[9036] = {[3] = 7,[4] = 11453},
		[9060] = {[3] = 5,[4] = 11454},
		[9061] = {[3] = 7,[4] = 11456},
		[9088] = {[3] = 7,[4] = 11466},
		[9144] = {[3] = 7,[4] = 11458},
		[9149] = {[3] = 7,[4] = 11459},
		[9154] = {[3] = 7,[4] = 11460},
		[9155] = {[3] = 7,[4] = 11461},
		[9172] = {[3] = 7,[4] = 11464},
		[9179] = {[3] = 7,[4] = 11465},
		[9186] = {[3] = 16,[4] = 11400},
		[9187] = {[3] = 7,[4] = 11467},
		[9197] = {[3] = 7,[4] = 11468},
		[9206] = {[3] = 7,[4] = 11472},
		[9210] = {[3] = 7,[4] = 11473},
		[9224] = {[3] = 7,[4] = 11477},
		[9233] = {[3] = 7,[4] = 11478},
		[9264] = {[3] = 7,[4] = 11476},
		[9312] = {[3] = 12,[4] = 23067},
		[9313] = {[3] = 12,[4] = 23068},
		[9318] = {[3] = 12,[4] = 23066},
		[9366] = {[3] = 5,[4] = 11643},
		[9718] = {[3] = 5,[4] = 11923},
		[9998] = {[3] = 11,[4] = 12048},
		[9999] = {[3] = 11,[4] = 12049},
		[10001] = {[3] = 11,[4] = 12050},
		[10002] = {[3] = 11,[4] = 12052},
		[10003] = {[3] = 11,[4] = 12053},
		[10004] = {[3] = 11,[4] = 12055},
		[10007] = {[3] = 11,[4] = 12056},
		[10008] = {[3] = 11,[4] = 12059},
		[10009] = {[3] = 11,[4] = 12060},
		[10010] = {[3] = 11,[4] = 12062},
		[10011] = {[3] = 11,[4] = 12063},
		[10018] = {[3] = 11,[4] = 12066},
		[10019] = {[3] = 11,[4] = 12067},
		[10020] = {[3] = 11,[4] = 12068},
		[10021] = {[3] = 11,[4] = 12070},
		[10023] = {[3] = 11,[4] = 12071},
		[10024] = {[3] = 11,[4] = 12072},
		[10025] = {[3] = 11,[4] = 12086},
		[10026] = {[3] = 11,[4] = 12073},
		[10027] = {[3] = 11,[4] = 12074},
		[10028] = {[3] = 11,[4] = 12076},
		[10029] = {[3] = 11,[4] = 12078},
		[10030] = {[3] = 11,[4] = 12081},
		[10031] = {[3] = 11,[4] = 12082},
		[10032] = {[3] = 11,[4] = 12083},
		[10033] = {[3] = 11,[4] = 12084},
		[10034] = {[3] = 11,[4] = 12085},
		[10035] = {[3] = 11,[4] = 12089},
		[10036] = {[3] = 11,[4] = 12093},
		[10038] = {[3] = 11,[4] = 12087},
		[10039] = {[3] = 11,[4] = 12090},
		[10040] = {[3] = 11,[4] = 12091},
		[10041] = {[3] = 11,[4] = 12092},
		[10042] = {[3] = 11,[4] = 12069},
		[10044] = {[3] = 11,[4] = 12088},
		[10045] = {[3] = 11,[4] = 12044},
		[10046] = {[3] = 11,[4] = 12045},
		[10047] = {[3] = 11,[4] = 12046},
		[10048] = {[3] = 11,[4] = 12047},
		[10050] = {[3] = 11,[4] = 12065},
		[10051] = {[3] = 11,[4] = 12079},
		[10052] = {[3] = 11,[4] = 12064},
		[10053] = {[3] = 11,[4] = 12077},
		[10054] = {[3] = 11,[4] = 12075},
		[10055] = {[3] = 11,[4] = 12080},
		[10056] = {[3] = 11,[4] = 12061},
		[10421] = {[3] = 5,[4] = 12260},
		[10423] = {[3] = 5,[4] = 12259},
		[10498] = {[3] = 12,[4] = 12590},
		[10499] = {[3] = 12,[4] = 12587},
		[10500] = {[3] = 12,[4] = 12594},
		[10501] = {[3] = 12,[4] = 12607},
		[10502] = {[3] = 12,[4] = 12615},
		[10503] = {[3] = 12,[4] = 12618},
		[10504] = {[3] = 12,[4] = 12622},
		[10505] = {[3] = 12,[4] = 12585},
		[10506] = {[3] = 12,[4] = 12617},
		[10507] = {[3] = 12,[4] = 12586},
		[10508] = {[3] = 12,[4] = 12595},
		[10510] = {[3] = 12,[4] = 12614},
		[10512] = {[3] = 12,[4] = 12596},
		[10513] = {[3] = 12,[4] = 12621},
		[10514] = {[3] = 12,[4] = 12603},
		[10518] = {[3] = 12,[4] = 12616},
		[10542] = {[3] = 12,[4] = 12717},
		[10543] = {[3] = 12,[4] = 12718},
		[10545] = {[3] = 12,[4] = 12897},
		[10546] = {[3] = 12,[4] = 12597},
		[10548] = {[3] = 12,[4] = 12620},
		[10558] = {[3] = 12,[4] = 12584},
		[10559] = {[3] = 12,[4] = 12589},
		[10560] = {[3] = 12,[4] = 12591},
		[10561] = {[3] = 12,[4] = 12599},
		[10562] = {[3] = 12,[4] = 12619},
		[10576] = {[3] = 12,[4] = 12624},
		[10577] = {[3] = 12,[4] = 13240},
		[10579] = {[3] = 12,[4] = 12719},
		[10580] = {[3] = 12,[4] = 12720},
		[10585] = {[3] = 12,[4] = 12722},
		[10586] = {[3] = 12,[4] = 12754},
		[10587] = {[3] = 12,[4] = 12755},
		[10588] = {[3] = 12,[4] = 12758},
		[10592] = {[3] = 7,[4] = 12609},
		[10644] = {[3] = 12,[4] = 12715},
		[10645] = {[3] = 12,[4] = 12759},
		[10646] = {[3] = 12,[4] = 12760},
		[10713] = {[3] = 12,[4] = 12895},
		[10716] = {[3] = 12,[4] = 12899},
		[10719] = {[3] = 12,[4] = 12900},
		[10720] = {[3] = 12,[4] = 12902},
		[10721] = {[3] = 12,[4] = 12903},
		[10723] = {[3] = 12,[4] = 12904},
		[10724] = {[3] = 12,[4] = 12905},
		[10725] = {[3] = 12,[4] = 12906},
		[10726] = {[3] = 12,[4] = 12907},
		[10727] = {[3] = 12,[4] = 12908},
		[10841] = {[3] = 9,[4] = 13028},
		[10918] = {[3] = 16,[4] = 13220},
		[10920] = {[3] = 16,[4] = 13228},
		[10921] = {[3] = 16,[4] = 13229},
		[10922] = {[3] = 16,[4] = 13230},
		[11128] = {[3] = 5,[4] = 14379},
		[11130] = {[3] = 13,[4] = 13628},
		[11144] = {[3] = 5,[4] = 14380},
		[11145] = {[3] = 13,[4] = 13702},
		[11287] = {[3] = 13,[4] = 14293},
		[11288] = {[3] = 13,[4] = 14807},
		[11289] = {[3] = 13,[4] = 14809},
		[11290] = {[3] = 13,[4] = 14810},
		[11371] = {[3] = 10,[4] = 14891},
		[11590] = {[3] = 12,[4] = 15255},
		[11604] = {[3] = 5,[4] = 15296},
		[11605] = {[3] = 5,[4] = 15295},
		[11606] = {[3] = 5,[4] = 15293},
		[11607] = {[3] = 5,[4] = 15294},
		[11608] = {[3] = 5,[4] = 15292},
		[11811] = {[3] = 13,[4] = 15596},
		[11825] = {[3] = 12,[4] = 15628},
		[11826] = {[3] = 12,[4] = 15633},
		[12190] = {[3] = 7,[4] = 15833},
		[12209] = {[3] = 9,[4] = 15853},
		[12210] = {[3] = 9,[4] = 15855},
		[12212] = {[3] = 9,[4] = 15861},
		[12213] = {[3] = 9,[4] = 15863},
		[12214] = {[3] = 9,[4] = 15865},
		[12215] = {[3] = 9,[4] = 15910},
		[12216] = {[3] = 9,[4] = 15915},
		[12217] = {[3] = 9,[4] = 15906},
		[12218] = {[3] = 9,[4] = 15933},
		[12224] = {[3] = 9,[4] = 15935},
		[12259] = {[3] = 5,[4] = 15972},
		[12260] = {[3] = 5,[4] = 15973},
		[12359] = {[3] = 10,[4] = 16153},
		[12360] = {[3] = 7,[4] = 17187},
		[12404] = {[3] = 5,[4] = 16641},
		[12405] = {[3] = 5,[4] = 16642},
		[12406] = {[3] = 5,[4] = 16643},
		[12408] = {[3] = 5,[4] = 16644},
		[12409] = {[3] = 5,[4] = 16652},
		[12410] = {[3] = 5,[4] = 16653},
		[12414] = {[3] = 5,[4] = 16662},
		[12415] = {[3] = 5,[4] = 16648},
		[12416] = {[3] = 5,[4] = 16645},
		[12417] = {[3] = 5,[4] = 16659},
		[12418] = {[3] = 5,[4] = 16654},
		[12419] = {[3] = 5,[4] = 16656},
		[12420] = {[3] = 5,[4] = 16725},
		[12422] = {[3] = 5,[4] = 16663},
		[12424] = {[3] = 5,[4] = 16647},
		[12425] = {[3] = 5,[4] = 16649},
		[12426] = {[3] = 5,[4] = 16657},
		[12427] = {[3] = 5,[4] = 16658},
		[12428] = {[3] = 5,[4] = 16646},
		[12429] = {[3] = 5,[4] = 16730},
		[12610] = {[3] = 5,[4] = 16664},
		[12611] = {[3] = 5,[4] = 16665},
		[12612] = {[3] = 5,[4] = 16726},
		[12613] = {[3] = 5,[4] = 16731},
		[12614] = {[3] = 5,[4] = 16732},
		[12618] = {[3] = 5,[4] = 16745},
		[12619] = {[3] = 5,[4] = 16744},
		[12620] = {[3] = 5,[4] = 16742},
		[12624] = {[3] = 5,[4] = 16650},
		[12625] = {[3] = 5,[4] = 16660},
		[12628] = {[3] = 5,[4] = 16667},
		[12631] = {[3] = 5,[4] = 16655},
		[12632] = {[3] = 5,[4] = 16661},
		[12633] = {[3] = 5,[4] = 16724},
		[12636] = {[3] = 5,[4] = 16728},
		[12639] = {[3] = 5,[4] = 16741},
		[12640] = {[3] = 5,[4] = 16729},
		[12641] = {[3] = 5,[4] = 16746},
		[12643] = {[3] = 5,[4] = 16640},
		[12644] = {[3] = 5,[4] = 16639},
		[12645] = {[3] = 5,[4] = 16651},
		[12655] = {[3] = 13,[4] = 17180},
		[12764] = {[3] = 5,[4] = 16960},
		[12769] = {[3] = 5,[4] = 16965},
		[12772] = {[3] = 5,[4] = 16967},
		[12773] = {[3] = 5,[4] = 16969},
		[12774] = {[3] = 5,[4] = 16970},
		[12775] = {[3] = 5,[4] = 16971},
		[12776] = {[3] = 5,[4] = 16973},
		[12777] = {[3] = 5,[4] = 16978},
		[12779] = {[3] = 5,[4] = 16980},
		[12781] = {[3] = 5,[4] = 16983},
		[12782] = {[3] = 5,[4] = 16985},
		[12783] = {[3] = 5,[4] = 16995},
		[12784] = {[3] = 5,[4] = 16994},
		[12790] = {[3] = 5,[4] = 16990},
		[12792] = {[3] = 5,[4] = 16984},
		[12794] = {[3] = 5,[4] = 16993},
		[12795] = {[3] = 5,[4] = 16986},
		[12796] = {[3] = 5,[4] = 16988},
		[12797] = {[3] = 5,[4] = 16992},
		[12798] = {[3] = 5,[4] = 16991},
		[12802] = {[3] = 5,[4] = 16987},
		[12803] = {[3] = 7,[4] = 17566},
		[12808] = {[3] = 7,[4] = 17564},
		[12810] = {[3] = 13,[4] = 17181},
		[13423] = {[3] = 7,[4] = 17551},
		[13442] = {[3] = 7,[4] = 17552},
		[13443] = {[3] = 7,[4] = 17553},
		[13444] = {[3] = 7,[4] = 17580},
		[13445] = {[3] = 7,[4] = 17554},
		[13446] = {[3] = 7,[4] = 17556},
		[13447] = {[3] = 7,[4] = 17555},
		[13452] = {[3] = 7,[4] = 17571},
		[13453] = {[3] = 7,[4] = 17557},
		[13454] = {[3] = 7,[4] = 17573},
		[13455] = {[3] = 7,[4] = 17570},
		[13456] = {[3] = 7,[4] = 17575},
		[13457] = {[3] = 7,[4] = 17574},
		[13458] = {[3] = 7,[4] = 17576},
		[13459] = {[3] = 7,[4] = 17578},
		[13460] = {[3] = 7,[4] = 17579},
		[13461] = {[3] = 7,[4] = 17577},
		[13462] = {[3] = 7,[4] = 17572},
		[13503] = {[3] = 7,[4] = 17632},
		[13506] = {[3] = 7,[4] = 17634},
		[13510] = {[3] = 7,[4] = 17635},
		[13511] = {[3] = 7,[4] = 17636},
		[13512] = {[3] = 7,[4] = 17637},
		[13513] = {[3] = 7,[4] = 17638},
		[13851] = {[3] = 9,[4] = 15856},
		[13856] = {[3] = 11,[4] = 18402},
		[13857] = {[3] = 11,[4] = 18407},
		[13858] = {[3] = 11,[4] = 18406},
		[13860] = {[3] = 11,[4] = 18409},
		[13863] = {[3] = 11,[4] = 18417},
		[13864] = {[3] = 11,[4] = 18423},
		[13865] = {[3] = 11,[4] = 18438},
		[13866] = {[3] = 11,[4] = 18444},
		[13867] = {[3] = 11,[4] = 18449},
		[13868] = {[3] = 11,[4] = 18404},
		[13869] = {[3] = 11,[4] = 18403},
		[13870] = {[3] = 11,[4] = 18411},
		[13871] = {[3] = 11,[4] = 18424},
		[13927] = {[3] = 9,[4] = 18239},
		[13928] = {[3] = 9,[4] = 18240},
		[13929] = {[3] = 9,[4] = 18242},
		[13930] = {[3] = 9,[4] = 18241},
		[13931] = {[3] = 9,[4] = 18243},
		[13932] = {[3] = 9,[4] = 18244},
		[13933] = {[3] = 9,[4] = 18245},
		[13934] = {[3] = 9,[4] = 18246},
		[13935] = {[3] = 9,[4] = 18247},
		[14042] = {[3] = 11,[4] = 18408},
		[14043] = {[3] = 11,[4] = 18412},
		[14044] = {[3] = 11,[4] = 18418},
		[14045] = {[3] = 11,[4] = 18434},
		[14046] = {[3] = 11,[4] = 18405},
		[14048] = {[3] = 11,[4] = 18401},
		[14100] = {[3] = 11,[4] = 18414},
		[14101] = {[3] = 11,[4] = 18415},
		[14103] = {[3] = 11,[4] = 18420},
		[14104] = {[3] = 11,[4] = 18439},
		[14106] = {[3] = 11,[4] = 18451},
		[14107] = {[3] = 11,[4] = 18419},
		[14108] = {[3] = 11,[4] = 18437},
		[14111] = {[3] = 11,[4] = 18442},
		[14112] = {[3] = 11,[4] = 18453},
		[14128] = {[3] = 11,[4] = 18446},
		[14130] = {[3] = 11,[4] = 18450},
		[14132] = {[3] = 11,[4] = 18421},
		[14134] = {[3] = 11,[4] = 18422},
		[14136] = {[3] = 11,[4] = 18436},
		[14137] = {[3] = 11,[4] = 18440},
		[14138] = {[3] = 11,[4] = 18447},
		[14139] = {[3] = 11,[4] = 18448},
		[14140] = {[3] = 11,[4] = 18452},
		[14141] = {[3] = 11,[4] = 18416},
		[14142] = {[3] = 11,[4] = 18413},
		[14143] = {[3] = 11,[4] = 18410},
		[14144] = {[3] = 11,[4] = 18441},
		[14146] = {[3] = 11,[4] = 18454},
		[14152] = {[3] = 11,[4] = 18457},
		[14153] = {[3] = 11,[4] = 18458},
		[14154] = {[3] = 11,[4] = 18456},
		[14155] = {[3] = 11,[4] = 18445},
		[14156] = {[3] = 11,[4] = 18455},
		[14342] = {[3] = 11,[4] = 18560},
		[14529] = {[3] = 4,[4] = 18629},
		[14530] = {[3] = 4,[4] = 18630},
		[15045] = {[3] = 6,[4] = 19050},
		[15046] = {[3] = 6,[4] = 19060},
		[15047] = {[3] = 6,[4] = 19054},
		[15048] = {[3] = 6,[4] = 19077},
		[15049] = {[3] = 6,[4] = 19089},
		[15050] = {[3] = 6,[4] = 19085},
		[15051] = {[3] = 6,[4] = 19094},
		[15052] = {[3] = 6,[4] = 19107},
		[15053] = {[3] = 6,[4] = 19076},
		[15054] = {[3] = 6,[4] = 19059},
		[15055] = {[3] = 6,[4] = 19101},
		[15056] = {[3] = 6,[4] = 19079},
		[15057] = {[3] = 6,[4] = 19067},
		[15058] = {[3] = 6,[4] = 19090},
		[15059] = {[3] = 6,[4] = 19095},
		[15060] = {[3] = 6,[4] = 19078},
		[15061] = {[3] = 6,[4] = 19061},
		[15062] = {[3] = 6,[4] = 19097},
		[15063] = {[3] = 6,[4] = 19084},
		[15064] = {[3] = 6,[4] = 19068},
		[15065] = {[3] = 6,[4] = 19080},
		[15066] = {[3] = 6,[4] = 19086},
		[15067] = {[3] = 6,[4] = 19062},
		[15068] = {[3] = 6,[4] = 19104},
		[15069] = {[3] = 6,[4] = 19074},
		[15070] = {[3] = 6,[4] = 19087},
		[15071] = {[3] = 6,[4] = 19066},
		[15072] = {[3] = 6,[4] = 19073},
		[15073] = {[3] = 6,[4] = 19063},
		[15074] = {[3] = 6,[4] = 19053},
		[15075] = {[3] = 6,[4] = 19081},
		[15076] = {[3] = 6,[4] = 19051},
		[15077] = {[3] = 6,[4] = 19048},
		[15078] = {[3] = 6,[4] = 19064},
		[15079] = {[3] = 6,[4] = 19075},
		[15080] = {[3] = 6,[4] = 19088},
		[15081] = {[3] = 6,[4] = 19100},
		[15082] = {[3] = 6,[4] = 19070},
		[15083] = {[3] = 6,[4] = 19049},
		[15084] = {[3] = 6,[4] = 19052},
		[15085] = {[3] = 6,[4] = 19098},
		[15086] = {[3] = 6,[4] = 19071},
		[15087] = {[3] = 6,[4] = 19083},
		[15088] = {[3] = 6,[4] = 19092},
		[15090] = {[3] = 6,[4] = 19102},
		[15091] = {[3] = 6,[4] = 19055},
		[15092] = {[3] = 6,[4] = 19065},
		[15093] = {[3] = 6,[4] = 19072},
		[15094] = {[3] = 6,[4] = 19082},
		[15095] = {[3] = 6,[4] = 19091},
		[15096] = {[3] = 6,[4] = 19103},
		[15138] = {[3] = 6,[4] = 19093},
		[15141] = {[3] = 6,[4] = 19106},
		[15407] = {[3] = 6,[4] = 19047},
		[15409] = {[3] = 6,[4] = 19566},
		[15564] = {[3] = 6,[4] = 19058},
		[15802] = {[3] = 11,[4] = 19435},
		[15846] = {[3] = 12,[4] = 19567},
		[15869] = {[3] = 5,[4] = 19666},
		[15870] = {[3] = 5,[4] = 19667},
		[15871] = {[3] = 5,[4] = 19668},
		[15872] = {[3] = 5,[4] = 19669},
		[15992] = {[3] = 12,[4] = 19788},
		[15993] = {[3] = 12,[4] = 19790},
		[15994] = {[3] = 12,[4] = 19791},
		[15995] = {[3] = 12,[4] = 19792},
		[15996] = {[3] = 12,[4] = 19793},
		[15997] = {[3] = 12,[4] = 19800},
		[15999] = {[3] = 12,[4] = 19794},
		[16000] = {[3] = 12,[4] = 19795},
		[16004] = {[3] = 12,[4] = 19796},
		[16005] = {[3] = 12,[4] = 19799},
		[16006] = {[3] = 12,[4] = 19815},
		[16007] = {[3] = 12,[4] = 19833},
		[16008] = {[3] = 12,[4] = 19825},
		[16009] = {[3] = 12,[4] = 19819},
		[16022] = {[3] = 12,[4] = 19830},
		[16023] = {[3] = 12,[4] = 19814},
		[16040] = {[3] = 12,[4] = 19831},
		[16206] = {[3] = 5,[4] = 20201},
		[16207] = {[3] = 13,[4] = 20051},
		[16766] = {[3] = 9,[4] = 20626},
		[16979] = {[3] = 11,[4] = 20849},
		[16980] = {[3] = 11,[4] = 20848},
		[16982] = {[3] = 6,[4] = 20853},
		[16983] = {[3] = 6,[4] = 20854},
		[16984] = {[3] = 6,[4] = 20855},
		[16988] = {[3] = 5,[4] = 20873},
		[16989] = {[3] = 5,[4] = 20872},
		[17013] = {[3] = 5,[4] = 20876},
		[17014] = {[3] = 5,[4] = 20874},
		[17015] = {[3] = 5,[4] = 20890},
		[17016] = {[3] = 5,[4] = 20897},
		[17193] = {[3] = 5,[4] = 21161},
		[17197] = {[3] = 9,[4] = 21143},
		[17198] = {[3] = 9,[4] = 21144},
		[17202] = {[3] = 12,[4] = 21935},
		[17222] = {[3] = 9,[4] = 21175},
		[17704] = {[3] = 5,[4] = 21913},
		[17708] = {[3] = 7,[4] = 21923},
		[17716] = {[3] = 12,[4] = 21940},
		[17721] = {[3] = 6,[4] = 21943},
		[17723] = {[3] = 11,[4] = 21945},
		[17771] = {[3] = 10,[4] = 22967},
		[18045] = {[3] = 9,[4] = 22480},
		[18168] = {[3] = 12,[4] = 22797},
		[18232] = {[3] = 12,[4] = 22704},
		[18238] = {[3] = 6,[4] = 22711},
		[18251] = {[3] = 6,[4] = 22727},
		[18253] = {[3] = 7,[4] = 22732},
		[18254] = {[3] = 9,[4] = 22761},
		[18258] = {[3] = 6,[4] = 22815},
		[18262] = {[3] = 5,[4] = 22757},
		[18263] = {[3] = 11,[4] = 22759},
		[18282] = {[3] = 12,[4] = 22795},
		[18283] = {[3] = 12,[4] = 22793},
		[18294] = {[3] = 7,[4] = 22808},
		[18405] = {[3] = 11,[4] = 22866},
		[18407] = {[3] = 11,[4] = 22867},
		[18408] = {[3] = 11,[4] = 22868},
		[18409] = {[3] = 11,[4] = 22869},
		[18413] = {[3] = 11,[4] = 22870},
		[18486] = {[3] = 11,[4] = 22902},
		[18504] = {[3] = 6,[4] = 22921},
		[18506] = {[3] = 6,[4] = 22922},
		[18508] = {[3] = 6,[4] = 22923},
		[18509] = {[3] = 6,[4] = 22926},
		[18510] = {[3] = 6,[4] = 22927},
		[18511] = {[3] = 6,[4] = 22928},
		[18587] = {[3] = 12,[4] = 23078},
		[18588] = {[3] = 12,[4] = 23069},
		[18594] = {[3] = 12,[4] = 23080},
		[18631] = {[3] = 12,[4] = 23071},
		[18634] = {[3] = 12,[4] = 23077},
		[18637] = {[3] = 12,[4] = 23079},
		[18638] = {[3] = 12,[4] = 23081},
		[18639] = {[3] = 12,[4] = 23082},
		[18641] = {[3] = 12,[4] = 23070},
		[18645] = {[3] = 12,[4] = 23096},
		[18660] = {[3] = 12,[4] = 23129},
		[18662] = {[3] = 6,[4] = 23190},
		[18948] = {[3] = 6,[4] = 23399},
		[18984] = {[3] = 12,[4] = 23486},
		[18986] = {[3] = 12,[4] = 23489},
		[19026] = {[3] = 12,[4] = 23507},
		[19043] = {[3] = 5,[4] = 23628},
		[19044] = {[3] = 6,[4] = 23703},
		[19047] = {[3] = 11,[4] = 23662},
		[19048] = {[3] = 5,[4] = 23629},
		[19049] = {[3] = 6,[4] = 23704},
		[19050] = {[3] = 11,[4] = 23663},
		[19051] = {[3] = 5,[4] = 23632},
		[19052] = {[3] = 6,[4] = 23705},
		[19056] = {[3] = 11,[4] = 23664},
		[19057] = {[3] = 5,[4] = 23633},
		[19058] = {[3] = 6,[4] = 23706},
		[19059] = {[3] = 11,[4] = 23665},
		[19148] = {[3] = 5,[4] = 23636},
		[19149] = {[3] = 6,[4] = 23707},
		[19156] = {[3] = 11,[4] = 23666},
		[19157] = {[3] = 6,[4] = 23708},
		[19162] = {[3] = 6,[4] = 23709},
		[19163] = {[3] = 6,[4] = 23710},
		[19164] = {[3] = 5,[4] = 23637},
		[19165] = {[3] = 11,[4] = 23667},
		[19166] = {[3] = 5,[4] = 23638},
		[19167] = {[3] = 5,[4] = 23639},
		[19168] = {[3] = 5,[4] = 23652},
		[19169] = {[3] = 5,[4] = 23653},
		[19170] = {[3] = 5,[4] = 23650},
		[19440] = {[3] = 4,[4] = 23787},
		[19682] = {[3] = 11,[4] = 24091},
		[19683] = {[3] = 11,[4] = 24092},
		[19684] = {[3] = 11,[4] = 24093},
		[19685] = {[3] = 6,[4] = 24121},
		[19686] = {[3] = 6,[4] = 24122},
		[19687] = {[3] = 6,[4] = 24123},
		[19688] = {[3] = 6,[4] = 24124},
		[19689] = {[3] = 6,[4] = 24125},
		[19690] = {[3] = 5,[4] = 24136},
		[19691] = {[3] = 5,[4] = 24137},
		[19692] = {[3] = 5,[4] = 24138},
		[19693] = {[3] = 5,[4] = 24139},
		[19694] = {[3] = 5,[4] = 24140},
		[19695] = {[3] = 5,[4] = 24141},
		[19931] = {[3] = 7,[4] = 24266},
		[19998] = {[3] = 12,[4] = 24357},
		[19999] = {[3] = 12,[4] = 24356},
		[20002] = {[3] = 7,[4] = 24366},
		[20004] = {[3] = 7,[4] = 24368},
		[20007] = {[3] = 7,[4] = 24365},
		[20008] = {[3] = 7,[4] = 24367},
		[20039] = {[3] = 5,[4] = 24399},
		[20074] = {[3] = 9,[4] = 24418},
		[20295] = {[3] = 6,[4] = 24654},
		[20296] = {[3] = 6,[4] = 24655},
		[20380] = {[3] = 6,[4] = 24703},
		[20452] = {[3] = 9,[4] = 24801},
		[20475] = {[3] = 12,[4] = 43676},
		[20476] = {[3] = 6,[4] = 24849},
		[20477] = {[3] = 6,[4] = 24850},
		[20478] = {[3] = 6,[4] = 24851},
		[20479] = {[3] = 6,[4] = 24848},
		[20480] = {[3] = 6,[4] = 24847},
		[20481] = {[3] = 6,[4] = 24846},
		[20537] = {[3] = 11,[4] = 24903},
		[20538] = {[3] = 11,[4] = 24901},
		[20539] = {[3] = 11,[4] = 24902},
		[20549] = {[3] = 5,[4] = 24912},
		[20550] = {[3] = 5,[4] = 24914},
		[20551] = {[3] = 5,[4] = 24913},
		[20575] = {[3] = 6,[4] = 24940},
		[20744] = {[3] = 13,[4] = 25124},
		[20745] = {[3] = 13,[4] = 25125},
		[20746] = {[3] = 13,[4] = 25126},
		[20747] = {[3] = 13,[4] = 25127},
		[20748] = {[3] = 13,[4] = 25130},
		[20749] = {[3] = 13,[4] = 25129},
		[20750] = {[3] = 13,[4] = 25128},
		[20816] = {[3] = 17,[4] = 25255},
		[20817] = {[3] = 17,[4] = 25278},
		[20818] = {[3] = 17,[4] = 25280},
		[20820] = {[3] = 17,[4] = 25284},
		[20821] = {[3] = 17,[4] = 25283},
		[20823] = {[3] = 17,[4] = 25287},
		[20826] = {[3] = 17,[4] = 25305},
		[20827] = {[3] = 17,[4] = 25317},
		[20828] = {[3] = 17,[4] = 25318},
		[20830] = {[3] = 17,[4] = 25339},
		[20831] = {[3] = 17,[4] = 25320},
		[20832] = {[3] = 17,[4] = 25321},
		[20833] = {[3] = 17,[4] = 25323},
		[20844] = {[3] = 16,[4] = 25347},
		[20906] = {[3] = 17,[4] = 25493},
		[20907] = {[3] = 17,[4] = 25490},
		[20909] = {[3] = 17,[4] = 25498},
		[20950] = {[3] = 17,[4] = 25610},
		[20954] = {[3] = 17,[4] = 25612},
		[20955] = {[3] = 17,[4] = 25613},
		[20956] = {[3] = 17,[4] = 25614},
		[20958] = {[3] = 17,[4] = 25617},
		[20959] = {[3] = 17,[4] = 25619},
		[20960] = {[3] = 17,[4] = 25620},
		[20961] = {[3] = 17,[4] = 25621},
		[20963] = {[3] = 17,[4] = 25615},
		[20964] = {[3] = 17,[4] = 26874},
		[20966] = {[3] = 17,[4] = 25618},
		[20967] = {[3] = 17,[4] = 25622},
		[20969] = {[3] = 17,[4] = 26878},
		[21023] = {[3] = 9,[4] = 25659},
		[21072] = {[3] = 9,[4] = 25704},
		[21154] = {[3] = 11,[4] = 26403},
		[21217] = {[3] = 9,[4] = 25954},
		[21277] = {[3] = 12,[4] = 26011},
		[21278] = {[3] = 6,[4] = 26279},
		[21340] = {[3] = 11,[4] = 26085},
		[21341] = {[3] = 11,[4] = 26086},
		[21342] = {[3] = 11,[4] = 26087},
		[21524] = {{11,2,1},{14,2,1},{15,2,1}},
		[21525] = {{3,1,1},{5,2,1},{7,3,1}},
		[21542] = {[3] = 11,[4] = 26407},
		[21546] = {[3] = 7,[4] = 26277},
		[21557] = {[3] = 12,[4] = 26418},
		[21558] = {[3] = 12,[4] = 26416},
		[21559] = {[3] = 12,[4] = 26417},
		[21569] = {[3] = 12,[4] = 26442},
		[21570] = {[3] = 12,[4] = 26443},
		[21571] = {[3] = 12,[4] = 26423},
		[21574] = {[3] = 12,[4] = 26424},
		[21576] = {[3] = 12,[4] = 26425},
		[21589] = {[3] = 12,[4] = 26420},
		[21590] = {[3] = 12,[4] = 26421},
		[21592] = {[3] = 12,[4] = 26422},
		[21714] = {[3] = 12,[4] = 26426},
		[21716] = {[3] = 12,[4] = 26427},
		[21718] = {[3] = 12,[4] = 26428},
		[21748] = {[3] = 17,[4] = 26872},
		[21752] = {[3] = 17,[4] = 26880},
		[21753] = {[3] = 17,[4] = 26896},
		[21754] = {[3] = 17,[4] = 26887},
		[21755] = {[3] = 17,[4] = 26876},
		[21756] = {[3] = 17,[4] = 26873},
		[21758] = {[3] = 17,[4] = 26875},
		[21760] = {[3] = 17,[4] = 26881},
		[21763] = {[3] = 17,[4] = 26882},
		[21764] = {[3] = 17,[4] = 26883},
		[21765] = {[3] = 17,[4] = 26885},
		[21766] = {[3] = 17,[4] = 26897},
		[21767] = {[3] = 17,[4] = 26902},
		[21768] = {[3] = 17,[4] = 26903},
		[21769] = {[3] = 17,[4] = 26900},
		[21774] = {[3] = 17,[4] = 26906},
		[21775] = {[3] = 17,[4] = 26907},
		[21777] = {[3] = 17,[4] = 26909},
		[21778] = {[3] = 17,[4] = 26910},
		[21779] = {[3] = 17,[4] = 26916},
		[21780] = {[3] = 17,[4] = 26920},
		[21784] = {[3] = 17,[4] = 26912},
		[21785] = {[3] = 17,[4] = 26904},
		[21786] = {[3] = 17,[4] = 26905},
		[21789] = {[3] = 17,[4] = 26914},
		[21790] = {[3] = 17,[4] = 26908},
		[21791] = {[3] = 17,[4] = 26911},
		[21792] = {[3] = 17,[4] = 26915},
		[21793] = {[3] = 17,[4] = 26918},
		[21835] = {[3] = 16,[4] = 26786},
		[21840] = {[3] = 11,[4] = 26745},
		[21841] = {[3] = 11,[4] = 26746},
		[21842] = {[3] = 11,[4] = 26747},
		[21843] = {[3] = 11,[4] = 26749},
		[21844] = {[3] = 11,[4] = 26750},
		[21845] = {[3] = 11,[4] = 26751},
		[21846] = {[3] = 11,[4] = 26752},
		[21847] = {[3] = 11,[4] = 26753},
		[21848] = {[3] = 11,[4] = 26754},
		[21849] = {[3] = 11,[4] = 26764},
		[21850] = {[3] = 11,[4] = 26765},
		[21851] = {[3] = 11,[4] = 26770},
		[21852] = {[3] = 11,[4] = 26771},
		[21853] = {[3] = 11,[4] = 26772},
		[21854] = {[3] = 11,[4] = 26773},
		[21855] = {[3] = 11,[4] = 26774},
		[21858] = {[3] = 11,[4] = 26755},
		[21859] = {[3] = 11,[4] = 26775},
		[21860] = {[3] = 11,[4] = 26776},
		[21861] = {[3] = 11,[4] = 26777},
		[21862] = {[3] = 11,[4] = 26778},
		[21863] = {[3] = 11,[4] = 26779},
		[21864] = {[3] = 11,[4] = 26780},
		[21865] = {[3] = 11,[4] = 26781},
		[21866] = {[3] = 11,[4] = 26782},
		[21867] = {[3] = 11,[4] = 26783},
		[21868] = {[3] = 11,[4] = 26784},
		[21869] = {[3] = 11,[4] = 26756},
		[21870] = {[3] = 11,[4] = 26757},
		[21871] = {[3] = 11,[4] = 26758},
		[21872] = {[3] = 11,[4] = 26759},
		[21873] = {[3] = 11,[4] = 26760},
		[21874] = {[3] = 11,[4] = 26761},
		[21875] = {[3] = 11,[4] = 26762},
		[21876] = {[3] = 11,[4] = 26763},
		[21882] = {17,17,1},
		[21884] = {[3] = 7,[4] = 28582},
		[21885] = {[3] = 7,[4] = 28580},
		[21886] = {[3] = 7,[4] = 28585},
		[21887] = {[3] = 6,[4] = 32454},
		[21903] = {17,17,1},
		[21904] = {17,17,1},
		[21905] = {13,6,1},
		[21906] = {15,8,1},
		[21907] = {15,3,1},
		[21927] = {[3] = 16,[4] = 26892},
		[21931] = {[3] = 17,[4] = 26925},
		[21932] = {[3] = 17,[4] = 26926},
		[21933] = {[3] = 17,[4] = 26927},
		[21934] = {[3] = 17,[4] = 26928},
		[21990] = {[3] = 4,[4] = 27032},
		[21991] = {[3] = 4,[4] = 27033},
		[22053] = {[3] = 16,[4] = 26969},
		[22054] = {[3] = 16,[4] = 27282},
		[22055] = {[3] = 16,[4] = 27283},
		[22191] = {[3] = 5,[4] = 27590},
		[22194] = {[3] = 5,[4] = 27589},
		[22195] = {[3] = 5,[4] = 27588},
		[22196] = {[3] = 5,[4] = 27587},
		[22197] = {[3] = 5,[4] = 27585},
		[22198] = {[3] = 5,[4] = 27586},
		[22246] = {[3] = 11,[4] = 27658},
		[22248] = {[3] = 11,[4] = 27659},
		[22249] = {[3] = 11,[4] = 27660},
		[22251] = {[3] = 11,[4] = 27724},
		[22252] = {[3] = 11,[4] = 27725},
		[22383] = {[3] = 5,[4] = 27832},
		[22384] = {[3] = 5,[4] = 27830},
		[22385] = {[3] = 5,[4] = 27829},
		[22445] = {[3] = 13,[4] = 28021},
		[22448] = {[3] = 13,[4] = 42615},
		[22449] = {[3] = 13,[4] = 28022},
		[22451] = {[3] = 7,[4] = 28569},
		[22452] = {[3] = 7,[4] = 28584},
		[22456] = {[3] = 7,[4] = 28581},
		[22457] = {[3] = 7,[4] = 28583},
		[22459] = {[3] = 13,[4] = 28028},
		[22460] = {[3] = 13,[4] = 28027},
		[22461] = {[3] = 13,[4] = 32664},
		[22462] = {[3] = 13,[4] = 32665},
		[22463] = {[3] = 13,[4] = 32667},
		[22521] = {[3] = 13,[4] = 28016},
		[22522] = {[3] = 13,[4] = 28019},
		[22533] = {10,4,1},
		[22539] = {11,5,1},
		[22543] = {4,5,1},
		[22544] = {5,4,1},
		[22545] = {17,17,1},
		[22554] = {3,6,1},
		[22556] = {13,6,1},
		[22559] = {17,5,1},
		[22560] = {17,12,1},
		[22561] = {17,11,1},
		[22573] = {[3] = 10,[4] = 35750},
		[22574] = {[3] = 10,[4] = 35751},
		[22645] = {[3] = 9,[4] = 28267},
		[22652] = {[3] = 11,[4] = 28207},
		[22654] = {[3] = 11,[4] = 28205},
		[22655] = {[3] = 11,[4] = 28209},
		[22658] = {[3] = 11,[4] = 28208},
		[22660] = {[3] = 11,[4] = 28210},
		[22661] = {[3] = 6,[4] = 28219},
		[22662] = {[3] = 6,[4] = 28220},
		[22663] = {[3] = 6,[4] = 28221},
		[22664] = {[3] = 6,[4] = 28222},
		[22665] = {[3] = 6,[4] = 28224},
		[22666] = {[3] = 6,[4] = 28223},
		[22669] = {[3] = 5,[4] = 28242},
		[22670] = {[3] = 5,[4] = 28243},
		[22671] = {[3] = 5,[4] = 28244},
		[22728] = {[3] = 12,[4] = 28327},
		[22756] = {[3] = 11,[4] = 28480},
		[22757] = {[3] = 11,[4] = 28481},
		[22758] = {[3] = 11,[4] = 28482},
		[22759] = {[3] = 6,[4] = 28472},
		[22760] = {[3] = 6,[4] = 28473},
		[22761] = {[3] = 6,[4] = 28474},
		[22762] = {[3] = 5,[4] = 28461},
		[22763] = {[3] = 5,[4] = 28462},
		[22764] = {[3] = 5,[4] = 28463},
		[22823] = {[3] = 7,[4] = 28543},
		[22824] = {[3] = 7,[4] = 28544},
		[22825] = {[3] = 7,[4] = 28545},
		[22826] = {[3] = 7,[4] = 28546},
		[22827] = {[3] = 7,[4] = 28549},
		[22828] = {[3] = 7,[4] = 28550},
		[22829] = {[3] = 7,[4] = 28551},
		[22830] = {[3] = 7,[4] = 28552},
		[22831] = {[3] = 7,[4] = 28553},
		[22832] = {[3] = 7,[4] = 28555},
		[22833] = {[3] = 7,[4] = 28556},
		[22834] = {[3] = 7,[4] = 28557},
		[22835] = {[3] = 7,[4] = 28558},
		[22836] = {[3] = 7,[4] = 28562},
		[22837] = {[3] = 7,[4] = 28563},
		[22838] = {[3] = 7,[4] = 28564},
		[22839] = {[3] = 7,[4] = 28565},
		[22840] = {[3] = 7,[4] = 28570},
		[22841] = {[3] = 7,[4] = 28571},
		[22842] = {[3] = 7,[4] = 28572},
		[22844] = {[3] = 7,[4] = 28573},
		[22845] = {[3] = 7,[4] = 28575},
		[22846] = {[3] = 7,[4] = 28576},
		[22847] = {[3] = 7,[4] = 28577},
		[22848] = {[3] = 7,[4] = 28578},
		[22849] = {[3] = 7,[4] = 28579},
		[22850] = {[3] = 7,[4] = 28586},
		[22851] = {[3] = 7,[4] = 28587},
		[22853] = {[3] = 7,[4] = 28588},
		[22854] = {[3] = 7,[4] = 28589},
		[22861] = {[3] = 7,[4] = 28590},
		[22866] = {[3] = 7,[4] = 28591},
		[22871] = {[3] = 7,[4] = 28554},
		[22920] = {{15,2,1},{15,8,1}},
		[22921] = {4,3,1},
		[22927] = {11,2,1},
		[23094] = {[3] = 17,[4] = 28903},
		[23095] = {[3] = 17,[4] = 28905},
		[23096] = {[3] = 17,[4] = 28906},
		[23097] = {[3] = 17,[4] = 28907},
		[23098] = {[3] = 17,[4] = 28910},
		[23099] = {[3] = 17,[4] = 28912},
		[23100] = {[3] = 17,[4] = 28914},
		[23101] = {[3] = 17,[4] = 28915},
		[23103] = {[3] = 17,[4] = 28916},
		[23104] = {[3] = 17,[4] = 28917},
		[23105] = {[3] = 17,[4] = 28918},
		[23106] = {[3] = 17,[4] = 28924},
		[23108] = {[3] = 17,[4] = 28925},
		[23109] = {[3] = 17,[4] = 28927},
		[23110] = {[3] = 17,[4] = 28933},
		[23111] = {[3] = 17,[4] = 28936},
		[23113] = {[3] = 17,[4] = 28938},
		[23114] = {[3] = 17,[4] = 28944},
		[23115] = {[3] = 17,[4] = 28947},
		[23116] = {[3] = 17,[4] = 28948},
		[23118] = {[3] = 17,[4] = 28950},
		[23119] = {[3] = 17,[4] = 28953},
		[23120] = {[3] = 17,[4] = 28955},
		[23121] = {[3] = 17,[4] = 28957},
		[23445] = {[3] = 10,[4] = 29356},
		[23446] = {[3] = 10,[4] = 29358},
		[23447] = {[3] = 10,[4] = 29359},
		[23448] = {[3] = 10,[4] = 29360},
		[23449] = {[3] = 10,[4] = 29361},
		[23482] = {[3] = 5,[4] = 29545},
		[23484] = {[3] = 5,[4] = 29547},
		[23487] = {[3] = 5,[4] = 29548},
		[23488] = {[3] = 5,[4] = 29549},
		[23489] = {[3] = 5,[4] = 29550},
		[23490] = {[3] = 5,[4] = 29556},
		[23491] = {[3] = 5,[4] = 29552},
		[23493] = {[3] = 5,[4] = 29551},
		[23494] = {[3] = 5,[4] = 29553},
		[23497] = {[3] = 5,[4] = 29557},
		[23498] = {[3] = 5,[4] = 29558},
		[23499] = {[3] = 5,[4] = 29565},
		[23502] = {[3] = 5,[4] = 29566},
		[23503] = {[3] = 5,[4] = 29568},
		[23504] = {[3] = 5,[4] = 29569},
		[23505] = {[3] = 5,[4] = 29571},
		[23506] = {[3] = 5,[4] = 29603},
		[23507] = {[3] = 5,[4] = 29606},
		[23508] = {[3] = 5,[4] = 29605},
		[23509] = {[3] = 5,[4] = 29610},
		[23510] = {[3] = 5,[4] = 29608},
		[23511] = {[3] = 5,[4] = 29611},
		[23512] = {[3] = 5,[4] = 29613},
		[23513] = {[3] = 5,[4] = 29617},
		[23514] = {[3] = 5,[4] = 29616},
		[23515] = {[3] = 5,[4] = 29614},
		[23516] = {[3] = 5,[4] = 29615},
		[23517] = {[3] = 5,[4] = 29619},
		[23518] = {[3] = 5,[4] = 29620},
		[23519] = {[3] = 5,[4] = 29621},
		[23520] = {[3] = 5,[4] = 29642},
		[23521] = {[3] = 5,[4] = 29643},
		[23522] = {[3] = 5,[4] = 29645},
		[23523] = {[3] = 5,[4] = 29629},
		[23524] = {[3] = 5,[4] = 29628},
		[23525] = {[3] = 5,[4] = 29630},
		[23526] = {[3] = 5,[4] = 29648},
		[23527] = {[3] = 5,[4] = 29649},
		[23528] = {[3] = 5,[4] = 29654},
		[23529] = {[3] = 5,[4] = 29656},
		[23530] = {[3] = 5,[4] = 29657},
		[23531] = {[3] = 5,[4] = 29658},
		[23532] = {[3] = 5,[4] = 29622},
		[23533] = {[3] = 5,[4] = 29662},
		[23534] = {[3] = 5,[4] = 29663},
		[23535] = {[3] = 5,[4] = 29664},
		[23536] = {[3] = 5,[4] = 29668},
		[23537] = {[3] = 5,[4] = 29669},
		[23538] = {[3] = 5,[4] = 29671},
		[23539] = {[3] = 5,[4] = 29672},
		[23540] = {[3] = 5,[4] = 29692},
		[23541] = {[3] = 5,[4] = 29693},
		[23542] = {[3] = 5,[4] = 29694},
		[23543] = {[3] = 5,[4] = 29695},
		[23544] = {[3] = 5,[4] = 29696},
		[23546] = {[3] = 5,[4] = 29697},
		[23554] = {[3] = 5,[4] = 29698},
		[23555] = {[3] = 5,[4] = 29699},
		[23556] = {[3] = 5,[4] = 29700},
		[23559] = {[3] = 5,[4] = 32284},
		[23563] = {[3] = 5,[4] = 34529},
		[23564] = {[3] = 5,[4] = 34530},
		[23565] = {[3] = 5,[4] = 36256},
		[23571] = {[3] = 7,[4] = 29688},
		[23573] = {[3] = 10,[4] = 29686},
		[23575] = {[3] = 5,[4] = 29728},
		[23576] = {[3] = 5,[4] = 29729},
		[23605] = {5,4,1},
		[23606] = {13,6,1},
		[23607] = {7,6,1},
		[23615] = {4,5,1},
		[23617] = {14,2,1},
		[23684] = {[3] = 4,[4] = 30021},
		[23723] = {3,4,1},
		[23735] = {3,1,1},
		[23736] = {[3] = 12,[4] = 30310},
		[23737] = {[3] = 12,[4] = 30311},
		[23742] = {[3] = 12,[4] = 30312},
		[23746] = {[3] = 12,[4] = 30313},
		[23747] = {[3] = 12,[4] = 30314},
		[23748] = {[3] = 12,[4] = 30315},
		[23758] = {[3] = 12,[4] = 30316},
		[23761] = {[3] = 12,[4] = 30317},
		[23762] = {[3] = 12,[4] = 30318},
		[23763] = {[3] = 12,[4] = 30325},
		[23764] = {[3] = 12,[4] = 30329},
		[23765] = {[3] = 12,[4] = 30332},
		[23766] = {[3] = 12,[4] = 30334},
		[23767] = {[3] = 12,[4] = 30337},
		[23768] = {[3] = 12,[4] = 30341},
		[23769] = {[3] = 12,[4] = 30342},
		[23770] = {[3] = 12,[4] = 30343},
		[23771] = {[3] = 12,[4] = 30344},
		[23772] = {[3] = 12,[4] = 30346},
		[23774] = {[3] = 12,[4] = 30348},
		[23775] = {[3] = 12,[4] = 30349},
		[23781] = {[3] = 12,[4] = 30303},
		[23782] = {[3] = 12,[4] = 30304},
		[23783] = {[3] = 12,[4] = 30305},
		[23784] = {[3] = 12,[4] = 30306},
		[23785] = {[3] = 12,[4] = 30307},
		[23786] = {[3] = 12,[4] = 30308},
		[23787] = {[3] = 12,[4] = 30309},
		[23793] = {[3] = 6,[4] = 32455},
		[23809] = {17,1,1},
		[23819] = {[3] = 12,[4] = 30547},
		[23820] = {[3] = 12,[4] = 30549},
		[23821] = {[3] = 12,[4] = 30548},
		[23824] = {[3] = 12,[4] = 30556},
		[23825] = {[3] = 12,[4] = 30570},
		[23826] = {[3] = 12,[4] = 30558},
		[23827] = {[3] = 12,[4] = 30560},
		[23828] = {[3] = 12,[4] = 30574},
		[23829] = {[3] = 12,[4] = 30575},
		[23831] = {[3] = 12,[4] = 30561},
		[23832] = {[3] = 12,[4] = 30573},
		[23835] = {[3] = 12,[4] = 30569},
		[23836] = {[3] = 12,[4] = 30563},
		[23838] = {[3] = 12,[4] = 30565},
		[23839] = {[3] = 12,[4] = 30566},
		[23840] = {[3] = 12,[4] = 30555},
		[23841] = {[3] = 12,[4] = 30568},
		[23857] = {17,17,1},
		[23862] = {17,17,1},
		[23864] = {17,17,1},
		[23865] = {17,17,1},
		[23881] = {1,1,1},
		[23886] = {1,2,1},
		[23887] = {10,2,1},
		[23891] = {1,3,1},
		[23933] = {17,12,1},
		[24020] = {1,1,1},
		[24021] = {1,1,1},
		[24022] = {1,1,1},
		[24023] = {1,1,1},
		[24024] = {1,1,1},
		[24027] = {[3] = 17,[4] = 31084},
		[24028] = {[3] = 17,[4] = 31085},
		[24029] = {[3] = 17,[4] = 31087},
		[24030] = {[3] = 17,[4] = 31088},
		[24031] = {[3] = 17,[4] = 31089},
		[24032] = {[3] = 17,[4] = 31090},
		[24033] = {[3] = 17,[4] = 31092},
		[24035] = {[3] = 17,[4] = 31149},
		[24036] = {[3] = 17,[4] = 31091},
		[24037] = {[3] = 17,[4] = 31094},
		[24039] = {[3] = 17,[4] = 31095},
		[24044] = {1,3,1},
		[24045] = {1,3,1},
		[24046] = {1,3,1},
		[24047] = {[3] = 17,[4] = 31096},
		[24048] = {[3] = 17,[4] = 31097},
		[24050] = {[3] = 17,[4] = 31099},
		[24051] = {[3] = 17,[4] = 31098},
		[24052] = {[3] = 17,[4] = 31100},
		[24053] = {[3] = 17,[4] = 31101},
		[24054] = {[3] = 17,[4] = 31102},
		[24055] = {[3] = 17,[4] = 31103},
		[24056] = {[3] = 17,[4] = 31104},
		[24057] = {[3] = 17,[4] = 31105},
		[24058] = {[3] = 17,[4] = 31106},
		[24059] = {[3] = 17,[4] = 31107},
		[24060] = {[3] = 17,[4] = 31108},
		[24061] = {[3] = 17,[4] = 31109},
		[24062] = {[3] = 17,[4] = 31110},
		[24063] = {1,3,1},
		[24064] = {1,3,1},
		[24065] = {[3] = 17,[4] = 31112},
		[24066] = {[3] = 17,[4] = 31111},
		[24067] = {[3] = 17,[4] = 31113},
		[24069] = {1,2,1},
		[24073] = {1,2,1},
		[24074] = {[3] = 17,[4] = 31048},
		[24075] = {[3] = 17,[4] = 31049},
		[24076] = {[3] = 17,[4] = 31050},
		[24077] = {[3] = 17,[4] = 31051},
		[24078] = {[3] = 17,[4] = 31052},
		[24079] = {[3] = 17,[4] = 31053},
		[24080] = {[3] = 17,[4] = 31054},
		[24082] = {[3] = 17,[4] = 31055},
		[24083] = {1,3,1},
		[24085] = {[3] = 17,[4] = 31056},
		[24086] = {[3] = 17,[4] = 31057},
		[24087] = {[3] = 17,[4] = 31058},
		[24088] = {[3] = 17,[4] = 31060},
		[24089] = {[3] = 17,[4] = 31061},
		[24090] = {1,2,1},
		[24091] = {1,2,1},
		[24092] = {[3] = 17,[4] = 31062},
		[24093] = {[3] = 17,[4] = 31063},
		[24094] = {1,2,1},
		[24095] = {[3] = 17,[4] = 31064},
		[24096] = {1,2,1},
		[24097] = {[3] = 17,[4] = 31065},
		[24098] = {[3] = 17,[4] = 31066},
		[24105] = {[3] = 9,[4] = 33277},
		[24106] = {[3] = 17,[4] = 31067},
		[24110] = {[3] = 17,[4] = 31068},
		[24114] = {[3] = 17,[4] = 31070},
		[24116] = {[3] = 17,[4] = 31071},
		[24117] = {[3] = 17,[4] = 31072},
		[24121] = {[3] = 17,[4] = 31076},
		[24122] = {[3] = 17,[4] = 31077},
		[24123] = {[3] = 17,[4] = 31078},
		[24124] = {[3] = 17,[4] = 31079},
		[24125] = {[3] = 17,[4] = 31080},
		[24126] = {[3] = 17,[4] = 31081},
		[24127] = {[3] = 17,[4] = 31082},
		[24128] = {[3] = 17,[4] = 31083},
		[24139] = {17,16,1},
		[24150] = {1,3,1},
		[24151] = {1,3,1},
		[24154] = {1,3,1},
		[24155] = {1,3,1},
		[24159] = {10,4,1},
		[24160] = {6,1,1},
		[24172] = {14,6,1},
		[24173] = {11,3,1},
		[24248] = {9,4,1},
		[24249] = {[3] = 11,[4] = 31434},
		[24250] = {[3] = 11,[4] = 31435},
		[24251] = {[3] = 11,[4] = 31437},
		[24252] = {[3] = 11,[4] = 31438},
		[24253] = {[3] = 11,[4] = 31440},
		[24254] = {[3] = 11,[4] = 31441},
		[24255] = {[3] = 11,[4] = 31442},
		[24256] = {[3] = 11,[4] = 31443},
		[24257] = {[3] = 11,[4] = 31444},
		[24258] = {[3] = 11,[4] = 31448},
		[24259] = {[3] = 11,[4] = 31449},
		[24260] = {[3] = 11,[4] = 31450},
		[24261] = {[3] = 11,[4] = 31451},
		[24262] = {[3] = 11,[4] = 31452},
		[24263] = {[3] = 11,[4] = 31453},
		[24264] = {[3] = 11,[4] = 31454},
		[24266] = {[3] = 11,[4] = 31455},
		[24267] = {[3] = 11,[4] = 31456},
		[24268] = {[3] = 11,[4] = 31460},
		[24269] = {[3] = 11,[4] = 31461},
		[24270] = {[3] = 11,[4] = 31459},
		[24271] = {[3] = 11,[4] = 31373},
		[24272] = {[3] = 11,[4] = 36686},
		[24273] = {[3] = 11,[4] = 31430},
		[24274] = {[3] = 11,[4] = 31432},
		[24275] = {[3] = 11,[4] = 31431},
		[24276] = {[3] = 11,[4] = 31433},
		[24308] = {13,2,1},
		[24309] = {7,4,1},
		[24310] = {14,3,1},
		[24311] = {14,5,1},
		[24312] = {3,1,1},
		[24313] = {10,3,1},
		[24356] = {8,1,1},
		[24357] = {8,1,1},
		[24359] = {8,1,1},
		[24360] = {8,1,1},
		[24361] = {8,1,1},
		[24362] = {8,3,1},
		[24363] = {8,3,1},
		[24364] = {8,3,1},
		[24365] = {8,3,1},
		[24366] = {8,3,1},
		[24367] = {10,4,1},
		[24368] = {10,4,1},
		[24376] = {8,2,1},
		[24378] = {8,2,1},
		[24379] = {8,2,1},
		[24380] = {8,2,1},
		[24381] = {8,2,1},
		[24384] = {2,1,1},
		[24385] = {2,1,1},
		[24386] = {2,1,1},
		[24387] = {2,1,1},
		[24388] = {2,1,1},
		[24389] = {2,2,1},
		[24390] = {2,2,1},
		[24391] = {2,2,1},
		[24392] = {2,2,1},
		[24393] = {2,2,1},
		[24394] = {2,3,1},
		[24395] = {2,3,1},
		[24396] = {2,3,1},
		[24397] = {2,3,1},
		[24398] = {2,3,1},
		[24413] = {9,1,1},
		[24450] = {9,1,1},
		[24451] = {9,1,1},
		[24452] = {9,1,1},
		[24453] = {9,3,1},
		[24454] = {9,3,1},
		[24455] = {9,3,1},
		[24456] = {9,3,1},
		[24457] = {9,3,1},
		[24458] = {9,2,1},
		[24459] = {9,2,1},
		[24460] = {9,2,1},
		[24461] = {9,2,1},
		[24462] = {9,2,1},
		[24463] = {9,4,1},
		[24464] = {9,4,1},
		[24465] = {9,4,1},
		[24466] = {9,4,1},
		[24481] = {9,4,1},
		[24488] = {13,5,1},
		[24514] = {7,5,1},
		[25438] = {[3] = 17,[4] = 32178},
		[25439] = {[3] = 17,[4] = 32179},
		[25461] = {[1] = 6,[2] = 1,[3] = 1,[5] = 1},
		[25462] = {[1] = 3,[2] = 1,[3] = 1,[5] = 1},
		[25498] = {[3] = 17,[4] = 32259},
		[25521] = {[3] = 5,[4] = 32285},
		[25650] = {[3] = 6,[4] = 32456},
		[25651] = {[3] = 6,[4] = 32457},
		[25652] = {[3] = 6,[4] = 32458},
		[25653] = {[3] = 6,[4] = 32461},
		[25654] = {[3] = 6,[4] = 32462},
		[25655] = {[3] = 6,[4] = 32463},
		[25656] = {[3] = 6,[4] = 32464},
		[25657] = {[3] = 6,[4] = 32465},
		[25659] = {[3] = 6,[4] = 32469},
		[25660] = {[3] = 6,[4] = 32468},
		[25661] = {[3] = 6,[4] = 32467},
		[25662] = {[3] = 6,[4] = 32466},
		[25668] = {[3] = 6,[4] = 32472},
		[25669] = {[3] = 6,[4] = 32470},
		[25670] = {[3] = 6,[4] = 32471},
		[25671] = {[3] = 6,[4] = 32473},
		[25673] = {[3] = 6,[4] = 32478},
		[25674] = {[3] = 6,[4] = 32479},
		[25675] = {[3] = 6,[4] = 32480},
		[25676] = {[3] = 6,[4] = 32481},
		[25679] = {[3] = 6,[4] = 32482},
		[25680] = {[3] = 6,[4] = 32485},
		[25681] = {[3] = 6,[4] = 32487},
		[25682] = {[3] = 6,[4] = 32489},
		[25683] = {[3] = 6,[4] = 32488},
		[25685] = {[3] = 6,[4] = 32490},
		[25686] = {[3] = 6,[4] = 32493},
		[25687] = {[3] = 6,[4] = 32494},
		[25689] = {[3] = 6,[4] = 32495},
		[25690] = {[3] = 6,[4] = 32496},
		[25691] = {[3] = 6,[4] = 32497},
		[25692] = {[3] = 6,[4] = 32502},
		[25693] = {[3] = 6,[4] = 32503},
		[25694] = {[3] = 6,[4] = 32501},
		[25695] = {[3] = 6,[4] = 32498},
		[25696] = {[3] = 6,[4] = 32500},
		[25697] = {[3] = 6,[4] = 32499},
		[25725] = {11,6,1},
		[25728] = {7,2,1},
		[25729] = {11,7,1},
		[25730] = {12,4,1},
		[25731] = {6,5,1},
		[25843] = {[3] = 5,[4] = 32655},
		[25844] = {[3] = 5,[4] = 32656},
		[25845] = {[3] = 5,[4] = 32657},
		[25867] = {[3] = 7,[4] = 32765},
		[25868] = {[3] = 7,[4] = 32766},
		[25880] = {[3] = 17,[4] = 32801},
		[25881] = {[3] = 17,[4] = 32807},
		[25882] = {[3] = 17,[4] = 32808},
		[25883] = {[3] = 17,[4] = 32809},
		[25884] = {[3] = 17,[4] = 32810},
		[25886] = {[3] = 12,[4] = 32814},
		[25890] = {[3] = 17,[4] = 32871},
		[25893] = {[3] = 17,[4] = 32872},
		[25894] = {[3] = 17,[4] = 32873},
		[25895] = {[3] = 17,[4] = 32874},
		[25896] = {[3] = 17,[4] = 32866},
		[25897] = {[3] = 17,[4] = 32867},
		[25898] = {[3] = 17,[4] = 32868},
		[25899] = {[3] = 17,[4] = 32869},
		[25901] = {[3] = 17,[4] = 32870},
		[25939] = {4,1,1},
		[25940] = {4,1,1},
		[25941] = {4,1,1},
		[25942] = {4,1,1},
		[25943] = {4,1,1},
		[25944] = {4,2,1},
		[25945] = {4,2,1},
		[25946] = {4,2,1},
		[25947] = {4,2,1},
		[25950] = {4,2,1},
		[25952] = {4,2,1},
		[25953] = {4,3,1},
		[25954] = {4,3,1},
		[25955] = {4,3,1},
		[25956] = {4,3,1},
		[25957] = {4,3,1},
		[25962] = {4,3,1},
		[25964] = {5,1,1},
		[26055] = {5,1,1},
		[27408] = {5,1,1},
		[27409] = {5,1,1},
		[27410] = {5,1,1},
		[27411] = {5,2,1},
		[27412] = {5,2,1},
		[27413] = {5,2,1},
		[27414] = {5,2,1},
		[27415] = {5,2,1},
		[27416] = {5,2,1},
		[27417] = {11,1,1},
		[27418] = {11,1,1},
		[27420] = {11,1,1},
		[27423] = {11,1,1},
		[27424] = {11,2,1},
		[27426] = {11,2,1},
		[27427] = {11,2,1},
		[27428] = {11,2,1},
		[27430] = {11,2,1},
		[27431] = {11,3,1},
		[27432] = {11,3,1},
		[27433] = {11,3,1},
		[27434] = {11,3,1},
		[27436] = {11,1,1},
		[27440] = {11,3,1},
		[27447] = {[1] = 1,[2] = 1,[3] = 1,[5] = 1},
		[27448] = {[1] = 1,[2] = 1,[3] = 1,[5] = 1},
		[27449] = {[1] = 1,[2] = 1,[3] = 1,[5] = 1},
		[27450] = {[1] = 1,[2] = 1,[3] = 1,[5] = 1},
		[27451] = {[1] = 1,[2] = 1,[3] = 1,[5] = 1},
		[27452] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27453] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27454] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27455] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27456] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27457] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27458] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27459] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27460] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27461] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[27462] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27463] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27464] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27465] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27466] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27467] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27468] = {7,2,1},
		[27474] = {3,4,1},
		[27475] = {10,3,1},
		[27476] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27477] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27478] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27483] = {[1] = 2,[2] = 1,[3] = 1,[5] = 1},
		[27484] = {[1] = 2,[2] = 1,[3] = 1,[5] = 1},
		[27485] = {[1] = 2,[2] = 1,[3] = 1,[5] = 1},
		[27487] = {[1] = 2,[2] = 1,[3] = 1,[5] = 1},
		[27488] = {[1] = 2,[2] = 1,[3] = 1,[5] = 1},
		[27489] = {[1] = 2,[2] = 2,[3] = 1,[5] = 1},
		[27490] = {[1] = 2,[2] = 2,[3] = 1,[5] = 1},
		[27491] = {[1] = 2,[2] = 2,[3] = 1,[5] = 1},
		[27492] = {[1] = 2,[2] = 2,[3] = 1,[5] = 1},
		[27493] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27494] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27495] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27497] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27505] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27506] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27507] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27508] = {10,1,1},
		[27509] = {12,3,1},
		[27510] = {10,3,1},
		[27512] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27514] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27517] = {3,1,1},
		[27518] = {3,1,1},
		[27519] = {3,1,1},
		[27520] = {3,1,1},
		[27521] = {3,1,1},
		[27522] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27523] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27524] = {3,3,1},
		[27525] = {3,3,1},
		[27526] = {3,3,1},
		[27527] = {3,4,1},
		[27528] = {3,4,1},
		[27529] = {3,4,1},
		[27531] = {3,4,1},
		[27533] = {3,4,1},
		[27534] = {3,4,1},
		[27535] = {3,4,1},
		[27536] = {3,4,1},
		[27537] = {3,4,1},
		[27538] = {3,4,1},
		[27539] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27540] = {3,4,1},
		[27541] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27542] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27543] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27544] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27545] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27546] = {[1] = 8,[2] = 1,[3] = 1,[5] = 1},
		[27547] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[27548] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[27549] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[27550] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[27551] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[27631] = {9,1,1},
		[27632] = {6,2,1},
		[27633] = {6,1,1},
		[27634] = {6,4,1},
		[27635] = {[3] = 9,[4] = 33276},
		[27636] = {[3] = 9,[4] = 33278},
		[27651] = {[3] = 9,[4] = 33279},
		[27655] = {[3] = 9,[4] = 33284},
		[27656] = {[3] = 9,[4] = 33285},
		[27657] = {[3] = 9,[4] = 33286},
		[27658] = {[3] = 9,[4] = 33287},
		[27659] = {[3] = 9,[4] = 33288},
		[27660] = {[3] = 9,[4] = 33289},
		[27661] = {[3] = 9,[4] = 33290},
		[27662] = {[3] = 9,[4] = 33291},
		[27663] = {[3] = 9,[4] = 33292},
		[27664] = {[3] = 9,[4] = 33293},
		[27665] = {[3] = 9,[4] = 33294},
		[27666] = {[3] = 9,[4] = 33295},
		[27667] = {[3] = 9,[4] = 33296},
		[27672] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27673] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27683] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27712] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27713] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27714] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27737] = {10,3,1},
		[27738] = {10,3,1},
		[27739] = {14,4,1},
		[27740] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27741] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27742] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27743] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27744] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27745] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27746] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27747] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27748] = {[1] = 9,[2] = 1,[3] = 1,[5] = 1},
		[27755] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27757] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27758] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27759] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27760] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27761] = {[1] = 9,[2] = 2,[3] = 1,[5] = 1},
		[27762] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27763] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27764] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27765] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27766] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27767] = {[1] = 9,[2] = 3,[3] = 1,[5] = 1},
		[27768] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27769] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27770] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27771] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27772] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27773] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27775] = {7,3,1},
		[27776] = {6,2,1},
		[27778] = {7,4,1},
		[27779] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27780] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27781] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27783] = {10,1,1},
		[27784] = {10,1,1},
		[27787] = {10,1,1},
		[27788] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[27789] = {10,1,1},
		[27790] = {10,2,1},
		[27791] = {10,2,1},
		[27792] = {10,2,1},
		[27793] = {10,2,1},
		[27794] = {10,2,1},
		[27795] = {10,3,1},
		[27796] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27797] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[27798] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27799] = {10,3,1},
		[27800] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[27801] = {10,3,1},
		[27802] = {3,3,1},
		[27803] = {7,4,1},
		[27804] = {10,3,1},
		[27805] = {10,3,1},
		[27806] = {10,3,1},
		[27813] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27814] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27815] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27816] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27817] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27818] = {[1] = 4,[2] = 1,[3] = 1,[5] = 1},
		[27821] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27822] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27823] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27824] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27825] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27826] = {[1] = 4,[2] = 2,[3] = 1,[5] = 1},
		[27827] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27828] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27829] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27831] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27835] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27837] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27838] = {6,2,1},
		[27839] = {12,3,1},
		[27840] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27842] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27843] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27844] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[27845] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27846] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27847] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27848] = {[1] = 2,[2] = 2,[3] = 1,[5] = 1},
		[27865] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27866] = {[1] = 5,[2] = 1,[3] = 1,[5] = 1},
		[27867] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27868] = {3,3,1},
		[27869] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27870] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27871] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27872] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[27873] = {12,3,1},
		[27874] = {10,3,1},
		[27875] = {6,2,1},
		[27876] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[27877] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[27878] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[27884] = {7,1,1},
		[27885] = {7,1,1},
		[27886] = {7,1,1},
		[27887] = {7,1,1},
		[27888] = {7,1,1},
		[27889] = {7,1,1},
		[27890] = {7,2,1},
		[27891] = {7,2,1},
		[27892] = {7,2,1},
		[27893] = {7,2,1},
		[27895] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27896] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27897] = {7,3,1},
		[27898] = {7,3,1},
		[27899] = {15,3,1},
		[27900] = {7,3,1},
		[27901] = {7,3,1},
		[27902] = {7,4,1},
		[27903] = {7,4,1},
		[27904] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[27905] = {7,4,1},
		[27906] = {[1] = 1,[2] = 2,[3] = 1,[5] = 1},
		[27907] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27908] = {7,4,1},
		[27909] = {7,4,1},
		[27910] = {7,4,1},
		[27911] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[27912] = {7,4,1},
		[27913] = {7,4,1},
		[27914] = {6,1,1},
		[27915] = {6,1,1},
		[27916] = {6,1,1},
		[27917] = {6,1,1},
		[27918] = {6,1,1},
		[27919] = {6,1,1},
		[27925] = {6,2,1},
		[27936] = {6,2,1},
		[27937] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[27938] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[27946] = {6,2,1},
		[27948] = {6,2,1},
		[27977] = {12,3,1},
		[27980] = {6,2,1},
		[27981] = {6,2,1},
		[27985] = {6,2,1},
		[27986] = {6,2,1},
		[27987] = {12,1,1},
		[27988] = {12,1,1},
		[27991] = {6,2,1},
		[27993] = {12,1,1},
		[27994] = {12,1,1},
		[27995] = {12,1,1},
		[27996] = {12,1,1},
		[28033] = {12,2,1},
		[28034] = {12,2,1},
		[28100] = {[3] = 7,[4] = 33732},
		[28101] = {[3] = 7,[4] = 33733},
		[28102] = {[3] = 7,[4] = 33738},
		[28103] = {[3] = 7,[4] = 33740},
		[28104] = {[3] = 7,[4] = 33741},
		[28121] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[28124] = {[1] = 8,[2] = 2,[3] = 1,[5] = 1},
		[28134] = {7,2,1},
		[28166] = {4,1,1},
		[28184] = {12,2,1},
		[28185] = {12,2,1},
		[28186] = {12,2,1},
		[28187] = {12,2,1},
		[28188] = {12,3,1},
		[28189] = {12,3,1},
		[28190] = {12,3,1},
		[28191] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28192] = {12,3,1},
		[28193] = {12,3,1},
		[28194] = {12,3,1},
		[28202] = {15,3,1},
		[28203] = {10,3,1},
		[28204] = {15,3,1},
		[28205] = {13,4,1},
		[28206] = {12,3,1},
		[28207] = {12,3,1},
		[28210] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28211] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28212] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28213] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28214] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28215] = {[1] = 11,[2] = 1,[3] = 1,[5] = 1},
		[28216] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28217] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28218] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28219] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28220] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28221] = {[1] = 11,[2] = 2,[3] = 1,[5] = 1},
		[28222] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28223] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28224] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28225] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28226] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28227] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28228] = {14,5,1},
		[28229] = {14,5,1},
		[28230] = {7,4,1},
		[28231] = {13,4,1},
		[28232] = {7,4,1},
		[28233] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28248] = {[1] = 15,[2] = 4,[3] = 1,[5] = 1},
		[28249] = {[1] = 15,[2] = 4,[3] = 1,[5] = 1},
		[28250] = {[1] = 15,[2] = 4,[3] = 1,[5] = 1},
		[28251] = {[1] = 15,[2] = 4,[3] = 1,[5] = 1},
		[28252] = {[1] = 15,[2] = 4,[3] = 1,[5] = 1},
		[28253] = {15,1,1},
		[28254] = {15,1,1},
		[28255] = {15,1,1},
		[28256] = {15,1,1},
		[28257] = {15,1,1},
		[28258] = {15,2,1},
		[28259] = {15,2,1},
		[28260] = {15,2,1},
		[28262] = {15,2,1},
		[28263] = {15,2,1},
		[28264] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[28265] = {15,3,1},
		[28266] = {15,3,1},
		[28267] = {15,3,1},
		[28268] = {[1] = 5,[2] = 3,[3] = 1,[5] = 1},
		[28269] = {15,3,1},
		[28275] = {15,3,1},
		[28278] = {15,3,1},
		[28285] = {15,3,1},
		[28286] = {15,3,1},
		[28288] = {15,3,1},
		[28290] = {[3] = 17,[4] = 34069},
		[28296] = {14,1,1},
		[28301] = {14,1,1},
		[28304] = {14,1,1},
		[28306] = {14,1,1},
		[28311] = {14,1,1},
		[28315] = {14,2,1},
		[28316] = {14,2,1},
		[28317] = {14,2,1},
		[28318] = {14,2,1},
		[28321] = {14,2,1},
		[28322] = {14,3,1},
		[28323] = {14,3,1},
		[28324] = {14,3,1},
		[28325] = {14,3,1},
		[28327] = {14,3,1},
		[28328] = {14,4,1},
		[28337] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[28338] = {14,4,1},
		[28339] = {14,4,1},
		[28340] = {14,4,1},
		[28341] = {14,5,1},
		[28342] = {14,5,1},
		[28343] = {14,5,1},
		[28344] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28345] = {14,5,1},
		[28347] = {14,5,1},
		[28348] = {14,5,1},
		[28349] = {14,5,1},
		[28350] = {14,5,1},
		[28367] = {14,5,1},
		[28370] = {14,5,1},
		[28371] = {14,5,1},
		[28372] = {13,1,1},
		[28373] = {13,1,1},
		[28374] = {13,1,1},
		[28375] = {13,1,1},
		[28384] = {13,1,1},
		[28386] = {13,2,1},
		[28387] = {13,2,1},
		[28390] = {13,2,1},
		[28391] = {13,2,1},
		[28392] = {13,2,1},
		[28393] = {13,3,1},
		[28394] = {13,3,1},
		[28396] = {13,3,1},
		[28397] = {13,3,1},
		[28398] = {13,3,1},
		[28400] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[28401] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[28403] = {13,4,1},
		[28406] = {13,4,1},
		[28407] = {13,4,1},
		[28412] = {13,4,1},
		[28413] = {13,4,1},
		[28414] = {13,4,1},
		[28415] = {13,4,1},
		[28416] = {13,4,1},
		[28418] = {13,4,1},
		[28419] = {13,4,1},
		[28420] = {[3] = 5,[4] = 34607},
		[28421] = {[3] = 5,[4] = 34608},
		[28425] = {[3] = 5,[4] = 34535},
		[28426] = {[3] = 5,[4] = 34537},
		[28427] = {[3] = 5,[4] = 36258},
		[28428] = {[3] = 5,[4] = 34538},
		[28429] = {[3] = 5,[4] = 34540},
		[28430] = {[3] = 5,[4] = 36259},
		[28431] = {[3] = 5,[4] = 34541},
		[28432] = {[3] = 5,[4] = 34542},
		[28433] = {[3] = 5,[4] = 36260},
		[28434] = {[3] = 5,[4] = 34543},
		[28435] = {[3] = 5,[4] = 34544},
		[28436] = {[3] = 5,[4] = 36261},
		[28437] = {[3] = 5,[4] = 34545},
		[28438] = {[3] = 5,[4] = 34546},
		[28439] = {[3] = 5,[4] = 36262},
		[28440] = {[3] = 5,[4] = 34547},
		[28441] = {[3] = 5,[4] = 34548},
		[28442] = {[3] = 5,[4] = 36263},
		[28453] = {17,1,1},
		[28454] = {17,1,1},
		[28477] = {17,1,1},
		[28483] = {[3] = 5,[4] = 34533},
		[28484] = {[3] = 5,[4] = 34534},
		[28485] = {[3] = 5,[4] = 36257},
		[28490] = {4,3,1},
		[28502] = {17,1,1},
		[28503] = {17,1,1},
		[28504] = {17,1,1},
		[28505] = {17,1,1},
		[28506] = {17,1,1},
		[28507] = {17,1,1},
		[28508] = {17,1,1},
		[28509] = {17,1,1},
		[28510] = {17,1,1},
		[28511] = {17,6,1},
		[28512] = {17,6,1},
		[28514] = {17,6,1},
		[28515] = {17,6,1},
		[28516] = {17,6,1},
		[28517] = {17,6,1},
		[28518] = {17,6,1},
		[28519] = {17,6,1},
		[28520] = {17,6,1},
		[28521] = {17,6,1},
		[28522] = {17,6,1},
		[28523] = {17,6,1},
		[28524] = {17,5,1},
		[28525] = {17,5,1},
		[28528] = {17,5,1},
		[28529] = {17,5,1},
		[28530] = {17,5,1},
		[28545] = {17,5,1},
		[28565] = {17,5,1},
		[28566] = {17,5,1},
		[28567] = {17,5,1},
		[28568] = {17,5,1},
		[28569] = {17,5,1},
		[28570] = {17,5,1},
		[28572] = {17,9,1},
		[28573] = {17,9,1},
		[28578] = {17,9,1},
		[28579] = {17,9,1},
		[28581] = {17,8,1},
		[28582] = {17,8,1},
		[28583] = {17,8,1},
		[28584] = {17,8,1},
		[28585] = {17,7,1},
		[28586] = {17,7,1},
		[28587] = {17,7,1},
		[28588] = {17,7,1},
		[28589] = {{17,7,1},{17,8,1},{17,9,1}},
		[28590] = {{17,7,1},{17,8,1},{17,9,1}},
		[28591] = {{17,7,1},{17,8,1},{17,9,1}},
		[28592] = {{17,7,1},{17,8,1},{17,9,1}},
		[28593] = {{17,7,1},{17,8,1},{17,9,1}},
		[28594] = {{17,7,1},{17,8,1},{17,9,1}},
		[28595] = {[3] = 17,[4] = 34590},
		[28597] = {17,16,1},
		[28599] = {17,16,1},
		[28600] = {17,16,1},
		[28601] = {17,16,1},
		[28602] = {17,16,1},
		[28603] = {17,16,1},
		[28604] = {17,16,1},
		[28606] = {17,16,1},
		[28608] = {17,16,1},
		[28609] = {17,16,1},
		[28610] = {17,16,1},
		[28611] = {17,16,1},
		[28612] = {17,10,1},
		[28621] = {17,10,1},
		[28631] = {17,10,1},
		[28633] = {17,10,1},
		[28647] = {17,10,1},
		[28649] = {17,10,1},
		[28652] = {17,11,1},
		[28653] = {17,11,1},
		[28654] = {17,11,1},
		[28655] = {17,11,1},
		[28656] = {17,11,1},
		[28657] = {17,11,1},
		[28658] = {17,11,1},
		[28659] = {17,11,1},
		[28660] = {17,11,1},
		[28661] = {17,11,1},
		[28662] = {17,11,1},
		[28663] = {17,12,1},
		[28666] = {17,12,1},
		[28669] = {17,12,1},
		[28670] = {17,12,1},
		[28671] = {17,12,1},
		[28672] = {17,12,1},
		[28673] = {17,12,1},
		[28674] = {17,12,1},
		[28675] = {17,12,1},
		[28726] = {17,12,1},
		[28727] = {17,12,1},
		[28728] = {17,12,1},
		[28729] = {17,13,1},
		[28730] = {17,13,1},
		[28731] = {17,13,1},
		[28732] = {17,13,1},
		[28733] = {17,13,1},
		[28734] = {17,13,1},
		[28735] = {17,13,1},
		[28740] = {17,13,1},
		[28741] = {17,13,1},
		[28742] = {17,13,1},
		[28743] = {17,13,1},
		[28744] = {17,13,1},
		[28745] = {17,14,1},
		[28746] = {17,14,1},
		[28747] = {17,14,1},
		[28748] = {17,14,1},
		[28749] = {17,14,1},
		[28750] = {17,14,1},
		[28751] = {17,14,1},
		[28752] = {17,14,1},
		[28753] = {17,14,1},
		[28754] = {17,14,1},
		[28755] = {17,14,1},
		[28756] = {17,14,1},
		[28757] = {17,15,1},
		[28762] = {17,15,1},
		[28763] = {17,15,1},
		[28764] = {17,15,1},
		[28765] = {17,15,1},
		[28766] = {17,15,1},
		[28767] = {17,15,1},
		[28768] = {17,15,1},
		[28769] = {14,1,1},
		[28770] = {17,15,1},
		[28771] = {17,15,1},
		[28772] = {17,15,1},
		[28773] = {17,15,1},
		[28774] = {20,1,1},
		[28775] = {20,1,1},
		[28776] = {20,1,1},
		[28777] = {20,1,1},
		[28778] = {20,1,1},
		[28779] = {20,1,1},
		[28780] = {20,1,1},
		[28781] = {20,1,1},
		[28782] = {20,1,1},
		[28783] = {20,1,1},
		[28785] = {17,11,1},
		[28789] = {20,1,1},
		[28790] = 32385,
		[28791] = 32385,
		[28792] = 32385,
		[28793] = 32385,
		[28794] = {21,2,1},
		[28795] = {21,1,1},
		[28796] = {21,1,1},
		[28797] = {21,1,1},
		[28799] = {21,1,1},
		[28800] = {21,1,1},
		[28801] = {21,1,1},
		[28802] = {21,2,1},
		[28803] = {21,2,1},
		[28804] = {21,2,1},
		[28810] = {21,2,1},
		[28822] = {21,2,1},
		[28823] = {21,2,1},
		[28824] = {21,2,1},
		[28825] = {21,2,1},
		[28826] = {21,2,1},
		[28827] = {21,2,1},
		[28828] = {21,2,1},
		[28830] = {21,2,1},
		[28963] = 29759,
		[28964] = 29755,
		[28966] = 29765,
		[28967] = 29762,
		[28968] = 29756,
		[29011] = 29761,
		[29012] = 29753,
		[29015] = 29767,
		[29016] = 29764,
		[29017] = 29758,
		[29019] = 29753,
		[29020] = 29758,
		[29021] = 29761,
		[29022] = 29767,
		[29023] = 29764,
		[29028] = 29760,
		[29029] = 29754,
		[29030] = 29766,
		[29031] = 29763,
		[29032] = 29757,
		[29033] = 29754,
		[29034] = 29757,
		[29035] = 29760,
		[29036] = 29766,
		[29037] = 29763,
		[29038] = 29754,
		[29039] = 29757,
		[29040] = 29760,
		[29042] = 29766,
		[29043] = 29763,
		[29044] = 29760,
		[29045] = 29754,
		[29046] = 29766,
		[29047] = 29763,
		[29048] = 29757,
		[29049] = 29761,
		[29050] = 29753,
		[29053] = 29767,
		[29054] = 29764,
		[29055] = 29758,
		[29056] = 29753,
		[29057] = 29758,
		[29058] = 29761,
		[29059] = 29767,
		[29060] = 29764,
		[29061] = 29760,
		[29062] = 29754,
		[29063] = 29766,
		[29064] = 29763,
		[29065] = 29757,
		[29066] = 29754,
		[29067] = 29757,
		[29068] = 29760,
		[29069] = 29766,
		[29070] = 29763,
		[29071] = 29754,
		[29072] = 29757,
		[29073] = 29760,
		[29074] = 29766,
		[29075] = 29763,
		[29076] = 29759,
		[29077] = 29755,
		[29078] = 29765,
		[29079] = 29762,
		[29080] = 29756,
		[29081] = 29759,
		[29082] = 29755,
		[29083] = 29765,
		[29084] = 29762,
		[29085] = 29756,
		[29086] = 29761,
		[29087] = 29753,
		[29088] = 29767,
		[29089] = 29764,
		[29090] = 29758,
		[29091] = 29753,
		[29092] = 29758,
		[29093] = 29761,
		[29094] = 29767,
		[29095] = 29764,
		[29096] = 29753,
		[29097] = 29758,
		[29098] = 29761,
		[29099] = 29767,
		[29100] = 29764,
		[29157] = {[3] = 17,[4] = 34955},
		[29158] = {[3] = 17,[4] = 34959},
		[29159] = {[3] = 17,[4] = 34960},
		[29160] = {[3] = 17,[4] = 34961},
		[29201] = {[3] = 5,[4] = 34979},
		[29202] = {[3] = 5,[4] = 34981},
		[29203] = {[3] = 5,[4] = 34982},
		[29204] = {[3] = 5,[4] = 34983},
		[29238] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[29239] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[29240] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[29241] = {[1] = 13,[2] = 4,[3] = 1,[5] = 1},
		[29242] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[29243] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[29244] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[29245] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[29246] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[29247] = {[1] = 12,[2] = 3,[3] = 1,[5] = 1},
		[29248] = {[1] = 13,[2] = 4,[3] = 1,[5] = 1},
		[29249] = {[1] = 6,[2] = 2,[3] = 1,[5] = 1},
		[29250] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[29251] = {[1] = 15,[2] = 3,[3] = 1,[5] = 1},
		[29252] = {[1] = 13,[2] = 4,[3] = 1,[5] = 1},
		[29253] = {[1] = 12,[2] = 3,[3] = 1,[5] = 1},
		[29254] = {[1] = 3,[2] = 4,[3] = 1,[5] = 1},
		[29255] = {[1] = 3,[2] = 4,[3] = 1,[5] = 1},
		[29257] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[29258] = {[1] = 14,[2] = 5,[3] = 1,[5] = 1},
		[29259] = {[1] = 6,[2] = 2,[3] = 1,[5] = 1},
		[29261] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[29262] = {[1] = 14,[2] = 5,[3] = 1,[5] = 1},
		[29263] = {[1] = 3,[2] = 4,[3] = 1,[5] = 1},
		[29264] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[29265] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[29346] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[29347] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[29348] = {[1] = 3,[2] = 4,[3] = 1,[5] = 1},
		[29349] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[29350] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[29351] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[29352] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[29353] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[29354] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[29355] = {[1] = 6,[2] = 2,[3] = 1,[5] = 1},
		[29356] = {[1] = 12,[2] = 3,[3] = 1,[5] = 1},
		[29357] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[29359] = {[1] = 14,[2] = 5,[3] = 1,[5] = 1},
		[29360] = {[1] = 13,[2] = 4,[3] = 1,[5] = 1},
		[29362] = {[1] = 15,[2] = 3,[3] = 1,[5] = 1},
		[29458] = {20,1,1},
		[29463] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[29483] = {[3] = 6,[4] = 35520},
		[29485] = {[3] = 6,[4] = 35521},
		[29486] = {[3] = 6,[4] = 35522},
		[29487] = {[3] = 6,[4] = 35523},
		[29488] = {[3] = 6,[4] = 35524},
		[29489] = {[3] = 6,[4] = 35525},
		[29490] = {[3] = 6,[4] = 35526},
		[29491] = {[3] = 6,[4] = 35527},
		[29492] = {[3] = 6,[4] = 35529},
		[29493] = {[3] = 6,[4] = 35528},
		[29494] = {[3] = 6,[4] = 35531},
		[29495] = {[3] = 6,[4] = 35532},
		[29496] = {[3] = 6,[4] = 35533},
		[29497] = {[3] = 6,[4] = 35534},
		[29498] = {[3] = 6,[4] = 35535},
		[29499] = {[3] = 6,[4] = 35536},
		[29500] = {[3] = 6,[4] = 35537},
		[29502] = {[3] = 6,[4] = 35558},
		[29503] = {[3] = 6,[4] = 35559},
		[29504] = {[3] = 6,[4] = 35560},
		[29505] = {[3] = 6,[4] = 35561},
		[29506] = {[3] = 6,[4] = 35562},
		[29507] = {[3] = 6,[4] = 35563},
		[29508] = {[3] = 6,[4] = 35564},
		[29509] = {[3] = 6,[4] = 35568},
		[29510] = {[3] = 6,[4] = 35572},
		[29511] = {[3] = 6,[4] = 35573},
		[29512] = {[3] = 6,[4] = 35567},
		[29514] = {[3] = 6,[4] = 35574},
		[29515] = {[3] = 6,[4] = 35575},
		[29516] = {[3] = 6,[4] = 35576},
		[29517] = {[3] = 6,[4] = 35577},
		[29519] = {[3] = 6,[4] = 35580},
		[29520] = {[3] = 6,[4] = 35582},
		[29521] = {[3] = 6,[4] = 35584},
		[29522] = {[3] = 6,[4] = 35585},
		[29523] = {[3] = 6,[4] = 35588},
		[29524] = {[3] = 6,[4] = 35587},
		[29525] = {[3] = 6,[4] = 35589},
		[29526] = {[3] = 6,[4] = 35590},
		[29527] = {[3] = 6,[4] = 35591},
		[29528] = {[3] = 6,[4] = 35540},
		[29529] = {[3] = 6,[4] = 35543},
		[29530] = {[3] = 6,[4] = 35544},
		[29531] = {[3] = 6,[4] = 351769},
		[29532] = {[3] = 6,[4] = 35538},
		[29533] = {[3] = 6,[4] = 35549},
		[29534] = {[3] = 6,[4] = 35555},
		[29535] = {[3] = 6,[4] = 35554},
		[29536] = {[3] = 6,[4] = 35557},
		[29540] = {[3] = 6,[4] = 35530},
		[29669] = {6,5,1},
		[29672] = {13,6,1},
		[29673] = {10,1,1},
		[29674] = {8,1,1},
		[29675] = {12,1,1},
		[29753] = {20,1,1},
		[29754] = {20,1,1},
		[29755] = {20,1,1},
		[29756] = {17,10,1},
		[29757] = {17,10,1},
		[29758] = {17,10,1},
		[29759] = {17,15,1},
		[29760] = {17,15,1},
		[29761] = {17,15,1},
		[29762] = {21,1,1},
		[29763] = {21,1,1},
		[29764] = {21,1,1},
		[29765] = {21,2,1},
		[29766] = {21,2,1},
		[29767] = {21,2,1},
		[29905] = {23,4,1},
		[29906] = {22,6,1},
		[29918] = {23,1,1},
		[29920] = {23,1,1},
		[29921] = {23,1,1},
		[29922] = {23,1,1},
		[29923] = {23,1,1},
		[29924] = {23,1,1},
		[29925] = {23,1,1},
		[29947] = {23,1,1},
		[29948] = {23,1,1},
		[29949] = {23,1,1},
		[29950] = {23,3,1},
		[29951] = {23,3,1},
		[29962] = {23,3,1},
		[29964] = {[3] = 6,[4] = 36074},
		[29965] = {23,3,1},
		[29966] = {23,3,1},
		[29970] = {[3] = 6,[4] = 36075},
		[29971] = {[3] = 6,[4] = 36076},
		[29972] = {23,3,1},
		[29973] = {[3] = 6,[4] = 36077},
		[29974] = {[3] = 6,[4] = 36078},
		[29975] = {[3] = 6,[4] = 36079},
		[29976] = {23,3,1},
		[29977] = {23,3,1},
		[29981] = {23,3,1},
		[29982] = {23,3,1},
		[29983] = {23,2,1},
		[29984] = {23,2,1},
		[29985] = {23,2,1},
		[29986] = {23,2,1},
		[29987] = {23,4,1},
		[29988] = {23,4,1},
		[29989] = {23,4,1},
		[29990] = {23,4,1},
		[29991] = {23,4,1},
		[29992] = {23,4,1},
		[29993] = {23,4,1},
		[29994] = {23,4,1},
		[29995] = {23,4,1},
		[29996] = {23,4,1},
		[29997] = {23,4,1},
		[29998] = {23,4,1},
		[30008] = {22,5,1},
		[30020] = {23,6,1},
		[30021] = {22,7,1},
		[30022] = {22,7,1},
		[30023] = {22,7,1},
		[30024] = {23,6,1},
		[30025] = {22,7,1},
		[30026] = {23,6,1},
		[30027] = {22,7,1},
		[30028] = {23,6,1},
		[30029] = {23,6,1},
		[30030] = {23,6,1},
		[30031] = {[3] = 5,[4] = 36392},
		[30032] = {[3] = 5,[4] = 36390},
		[30033] = {[3] = 5,[4] = 36391},
		[30034] = {[3] = 5,[4] = 36389},
		[30035] = {[3] = 11,[4] = 36318},
		[30036] = {[3] = 11,[4] = 36316},
		[30037] = {[3] = 11,[4] = 36317},
		[30038] = {[3] = 11,[4] = 36315},
		[30039] = {[3] = 6,[4] = 36357},
		[30040] = {[3] = 6,[4] = 36351},
		[30041] = {[3] = 6,[4] = 36355},
		[30042] = {[3] = 6,[4] = 36349},
		[30043] = {[3] = 6,[4] = 36359},
		[30044] = {[3] = 6,[4] = 36353},
		[30045] = {[3] = 6,[4] = 36358},
		[30046] = {[3] = 6,[4] = 36352},
		[30047] = {22,1,1},
		[30048] = {22,1,1},
		[30049] = {22,1,1},
		[30050] = {22,1,1},
		[30051] = {22,1,1},
		[30052] = {22,1,1},
		[30053] = {22,1,1},
		[30054] = {22,1,1},
		[30055] = {22,1,1},
		[30056] = {22,1,1},
		[30057] = {22,2,1},
		[30058] = {22,2,1},
		[30059] = {22,2,1},
		[30060] = {22,2,1},
		[30061] = {22,2,1},
		[30062] = {22,2,1},
		[30063] = {22,2,1},
		[30064] = {22,2,1},
		[30065] = {22,2,1},
		[30066] = {22,2,1},
		[30067] = {22,2,1},
		[30068] = {22,5,1},
		[30069] = {[3] = 5,[4] = 36122},
		[30070] = {[3] = 5,[4] = 36124},
		[30071] = {[3] = 5,[4] = 36125},
		[30072] = {[3] = 5,[4] = 36126},
		[30073] = {[3] = 5,[4] = 36128},
		[30074] = {[3] = 5,[4] = 36129},
		[30075] = {22,5,1},
		[30076] = {[3] = 5,[4] = 36130},
		[30077] = {[3] = 5,[4] = 36131},
		[30079] = {22,5,1},
		[30080] = {22,5,1},
		[30081] = {22,5,1},
		[30082] = {22,5,1},
		[30083] = {22,5,1},
		[30084] = {22,5,1},
		[30085] = {22,5,1},
		[30086] = {[3] = 5,[4] = 36133},
		[30087] = {[3] = 5,[4] = 36134},
		[30088] = {[3] = 5,[4] = 36135},
		[30089] = {[3] = 5,[4] = 36136},
		[30090] = {22,4,1},
		[30091] = {22,3,1},
		[30092] = {22,3,1},
		[30093] = {[3] = 5,[4] = 36137},
		[30095] = {22,3,1},
		[30096] = {22,3,1},
		[30097] = {22,3,1},
		[30098] = {22,5,1},
		[30099] = {22,4,1},
		[30100] = {22,4,1},
		[30101] = {22,4,1},
		[30102] = {22,6,1},
		[30103] = {22,6,1},
		[30104] = {22,6,1},
		[30105] = {22,6,1},
		[30106] = {22,6,1},
		[30107] = {22,6,1},
		[30108] = {22,6,1},
		[30109] = {22,6,1},
		[30110] = {22,6,1},
		[30111] = {22,6,1},
		[30112] = {22,6,1},
		[30113] = 30237,
		[30114] = 30240,
		[30115] = 30243,
		[30116] = 30246,
		[30117] = 30249,
		[30118] = 30237,
		[30119] = 30240,
		[30120] = 30243,
		[30121] = 30246,
		[30122] = 30249,
		[30123] = 30236,
		[30124] = 30239,
		[30125] = 30242,
		[30126] = 30245,
		[30127] = 30248,
		[30129] = 30236,
		[30130] = 30239,
		[30131] = 30242,
		[30132] = 30245,
		[30133] = 30248,
		[30134] = 30236,
		[30135] = 30239,
		[30136] = 30242,
		[30137] = 30245,
		[30138] = 30248,
		[30139] = 30238,
		[30140] = 30241,
		[30141] = 30244,
		[30142] = 30247,
		[30143] = 30250,
		[30144] = 30236,
		[30145] = 30239,
		[30146] = 30242,
		[30148] = 30245,
		[30149] = 30248,
		[30150] = 30237,
		[30151] = 30240,
		[30152] = 30243,
		[30153] = 30246,
		[30154] = 30249,
		[30155] = {[3] = 9,[4] = 36210},
		[30159] = 30237,
		[30160] = 30240,
		[30161] = 30243,
		[30162] = 30246,
		[30163] = 30249,
		[30164] = 30236,
		[30165] = 30239,
		[30166] = 30242,
		[30167] = 30245,
		[30168] = 30248,
		[30169] = 30236,
		[30170] = 30239,
		[30171] = 30242,
		[30172] = 30245,
		[30173] = 30248,
		[30183] = {{22,7,1},{23,6,1}},
		[30185] = 30236,
		[30189] = 30239,
		[30190] = 30242,
		[30192] = 30245,
		[30194] = 30248,
		[30196] = 30238,
		[30205] = 30241,
		[30206] = 30244,
		[30207] = 30247,
		[30210] = 30250,
		[30211] = 30241,
		[30212] = 30244,
		[30213] = 30247,
		[30214] = 30238,
		[30215] = 30250,
		[30216] = 30237,
		[30217] = 30240,
		[30219] = 30243,
		[30220] = 30246,
		[30221] = 30249,
		[30222] = 30237,
		[30223] = 30240,
		[30228] = 30243,
		[30229] = 30246,
		[30230] = 30249,
		[30231] = 30237,
		[30232] = 30240,
		[30233] = 30243,
		[30234] = 30246,
		[30235] = 30249,
		[30236] = {23,4,1},
		[30237] = {23,4,1},
		[30238] = {23,4,1},
		[30239] = {22,3,1},
		[30240] = {22,3,1},
		[30241] = {22,3,1},
		[30242] = {22,6,1},
		[30243] = {22,6,1},
		[30244] = {22,6,1},
		[30245] = {22,4,1},
		[30246] = {22,4,1},
		[30247] = {22,4,1},
		[30248] = {23,2,1},
		[30249] = {23,2,1},
		[30250] = {23,2,1},
		[30280] = {{22,7,1},{23,6,1}},
		[30281] = {{22,7,1},{23,6,1}},
		[30282] = {{22,7,1},{23,6,1}},
		[30283] = {{22,7,1},{23,6,1}},
		[30301] = {{22,7,1},{23,6,1}},
		[30302] = {{22,7,1},{23,6,1}},
		[30303] = {{22,7,1},{23,6,1}},
		[30304] = {{22,7,1},{23,6,1}},
		[30305] = {{22,7,1},{23,6,1}},
		[30306] = {{22,7,1},{23,6,1}},
		[30307] = {{22,7,1},{23,6,1}},
		[30308] = {{22,7,1},{23,6,1}},
		[30311] = {23,5,1},
		[30312] = {23,5,1},
		[30313] = {23,5,1},
		[30314] = {23,5,1},
		[30316] = {23,5,1},
		[30317] = {23,5,1},
		[30318] = {23,5,1},
		[30319] = {23,5,1},
		[30321] = {{22,7,1},{23,6,1}},
		[30322] = {{22,7,1},{23,6,1}},
		[30323] = {{22,7,1},{23,6,1}},
		[30324] = {{22,7,1},{23,6,1}},
		[30419] = {[3] = 17,[4] = 36523},
		[30420] = {[3] = 17,[4] = 36524},
		[30421] = {[3] = 17,[4] = 36525},
		[30422] = {[3] = 17,[4] = 36526},
		[30436] = {15,5,1},
		[30437] = {15,6,1},
		[30446] = {23,3,1},
		[30447] = {23,1,1},
		[30448] = {23,1,1},
		[30449] = {23,3,1},
		[30450] = {23,2,1},
		[30459] = {[3] = 11,[4] = 36665},
		[30460] = {[3] = 11,[4] = 36667},
		[30461] = {[3] = 11,[4] = 36668},
		[30463] = {[3] = 11,[4] = 36670},
		[30464] = {[3] = 11,[4] = 36672},
		[30465] = {[3] = 11,[4] = 36669},
		[30480] = {17,1,1},
		[30531] = {[1] = 12,[2] = 3,[3] = 1,[5] = 1},
		[30532] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[30533] = {[1] = 15,[2] = 3,[3] = 1,[5] = 1},
		[30534] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[30535] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[30536] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[30538] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[30541] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[30542] = {[3] = 12,[4] = 36954},
		[30543] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[30544] = {[3] = 12,[4] = 36955},
		[30546] = {{[1] = 3,[2] = 1,[3] = 1,[5] = 1},{[1] = 3,[2] = 2,[3] = 1,[5] = 1},{[1] = 3,[2] = 3,[3] = 1,[5] = 1},{[1] = 3,[2] = 4,[3] = 1,[5] = 1}},
		[30547] = {{[1] = 3,[2] = 1,[3] = 1,[5] = 1},{[1] = 3,[2] = 2,[3] = 1,[5] = 1},{[1] = 3,[2] = 3,[3] = 1,[5] = 1},{[1] = 3,[2] = 4,[3] = 1,[5] = 1}},
		[30548] = {{[1] = 3,[2] = 1,[3] = 1,[5] = 1},{[1] = 3,[2] = 2,[3] = 1,[5] = 1},{[1] = 3,[2] = 3,[3] = 1,[5] = 1},{[1] = 3,[2] = 4,[3] = 1,[5] = 1}},
		[30549] = {{[1] = 10,[2] = 1,[3] = 1,[5] = 1},{[1] = 10,[2] = 2,[3] = 1,[5] = 1},{[1] = 10,[2] = 3,[3] = 1,[5] = 1}},
		[30550] = {{[1] = 10,[2] = 1,[3] = 1,[5] = 1},{[1] = 10,[2] = 2,[3] = 1,[5] = 1},{[1] = 10,[2] = 3,[3] = 1,[5] = 1}},
		[30551] = {{[1] = 10,[2] = 1,[3] = 1,[5] = 1},{[1] = 10,[2] = 2,[3] = 1,[5] = 1},{[1] = 10,[2] = 3,[3] = 1,[5] = 1}},
		[30552] = {{[1] = 6,[2] = 1,[3] = 1,[5] = 1},{[1] = 6,[2] = 2,[3] = 1,[5] = 1},{[1] = 6,[2] = 3,[3] = 1,[5] = 1}},
		[30553] = {{[1] = 6,[2] = 1,[3] = 1,[5] = 1},{[1] = 6,[2] = 2,[3] = 1,[5] = 1},{[1] = 6,[2] = 3,[3] = 1,[5] = 1}},
		[30554] = {{[1] = 6,[2] = 1,[3] = 1,[5] = 1},{[1] = 6,[2] = 2,[3] = 1,[5] = 1},{[1] = 6,[2] = 3,[3] = 1,[5] = 1}},
		[30555] = {{[1] = 12,[2] = 1,[3] = 1,[5] = 1},{[1] = 12,[2] = 2,[3] = 1,[5] = 1},{[1] = 12,[2] = 3,[3] = 1,[5] = 1}},
		[30556] = {{[1] = 12,[2] = 1,[3] = 1,[5] = 1},{[1] = 12,[2] = 2,[3] = 1,[5] = 1},{[1] = 12,[2] = 3,[3] = 1,[5] = 1}},
		[30558] = {{[1] = 12,[2] = 1,[3] = 1,[5] = 1},{[1] = 12,[2] = 2,[3] = 1,[5] = 1},{[1] = 12,[2] = 3,[3] = 1,[5] = 1}},
		[30559] = {{[1] = 7,[2] = 1,[3] = 1,[5] = 1},{[1] = 7,[2] = 2,[3] = 1,[5] = 1},{[1] = 7,[2] = 3,[3] = 1,[5] = 1},{[1] = 7,[2] = 4,[3] = 1,[5] = 1}},
		[30560] = {{[1] = 7,[2] = 1,[3] = 1,[5] = 1},{[1] = 7,[2] = 2,[3] = 1,[5] = 1},{[1] = 7,[2] = 3,[3] = 1,[5] = 1},{[1] = 7,[2] = 4,[3] = 1,[5] = 1}},
		[30563] = {{[1] = 7,[2] = 1,[3] = 1,[5] = 1},{[1] = 7,[2] = 2,[3] = 1,[5] = 1},{[1] = 7,[2] = 3,[3] = 1,[5] = 1},{[1] = 7,[2] = 4,[3] = 1,[5] = 1}},
		[30564] = {{[1] = 15,[2] = 1,[3] = 1,[5] = 1},{[1] = 15,[2] = 2,[3] = 1,[5] = 1},{[1] = 15,[2] = 3,[3] = 1,[5] = 1}},
		[30565] = {{[1] = 15,[2] = 1,[3] = 1,[5] = 1},{[1] = 15,[2] = 2,[3] = 1,[5] = 1},{[1] = 15,[2] = 3,[3] = 1,[5] = 1}},
		[30566] = {{[1] = 15,[2] = 1,[3] = 1,[5] = 1},{[1] = 15,[2] = 2,[3] = 1,[5] = 1},{[1] = 15,[2] = 3,[3] = 1,[5] = 1}},
		[30572] = {[1] = 14,[3] = 1,[5] = 1},
		[30573] = {[1] = 14,[3] = 1,[5] = 1},
		[30574] = {[1] = 14,[3] = 1,[5] = 1},
		[30575] = {{[1] = 13,[2] = 1,[3] = 1,[5] = 1},{[1] = 13,[2] = 2,[3] = 1,[5] = 1},{[1] = 13,[2] = 3,[3] = 1,[5] = 1},{[1] = 13,[2] = 4,[3] = 1,[5] = 1}},
		[30581] = {{[1] = 13,[2] = 1,[3] = 1,[5] = 1},{[1] = 13,[2] = 2,[3] = 1,[5] = 1},{[1] = 13,[2] = 3,[3] = 1,[5] = 1},{[1] = 13,[2] = 4,[3] = 1,[5] = 1}},
		[30582] = {{[1] = 13,[2] = 1,[3] = 1,[5] = 1},{[1] = 13,[2] = 2,[3] = 1,[5] = 1},{[1] = 13,[2] = 3,[3] = 1,[5] = 1},{[1] = 13,[2] = 4,[3] = 1,[5] = 1}},
		[30583] = {{[1] = 4,[2] = 1,[3] = 1,[5] = 1},{[1] = 4,[2] = 2,[3] = 1,[5] = 1},{[1] = 4,[2] = 3,[3] = 1,[5] = 1},{[1] = 4,[2] = 4,[3] = 1,[5] = 1}},
		[30584] = {{[1] = 4,[2] = 1,[3] = 1,[5] = 1},{[1] = 4,[2] = 2,[3] = 1,[5] = 1},{[1] = 4,[2] = 3,[3] = 1,[5] = 1},{[1] = 4,[2] = 4,[3] = 1,[5] = 1}},
		[30585] = {{[1] = 4,[2] = 1,[3] = 1,[5] = 1},{[1] = 4,[2] = 2,[3] = 1,[5] = 1},{[1] = 4,[2] = 3,[3] = 1,[5] = 1},{[1] = 4,[2] = 4,[3] = 1,[5] = 1}},
		[30586] = {{[1] = 5,[2] = 1,[3] = 1,[5] = 1},{[1] = 5,[2] = 2,[3] = 1,[5] = 1}},
		[30587] = {{[1] = 5,[2] = 1,[3] = 1,[5] = 1},{[1] = 5,[2] = 2,[3] = 1,[5] = 1}},
		[30588] = {{[1] = 5,[2] = 1,[3] = 1,[5] = 1},{[1] = 5,[2] = 2,[3] = 1,[5] = 1}},
		[30589] = {{[1] = 11,[2] = 1,[3] = 1,[5] = 1},{[1] = 11,[2] = 2,[3] = 1,[5] = 1},{[1] = 11,[2] = 3,[3] = 1,[5] = 1}},
		[30590] = {{[1] = 11,[2] = 1,[3] = 1,[5] = 1},{[1] = 11,[2] = 2,[3] = 1,[5] = 1},{[1] = 11,[2] = 3,[3] = 1,[5] = 1}},
		[30591] = {{[1] = 11,[2] = 1,[3] = 1,[5] = 1},{[1] = 11,[2] = 2,[3] = 1,[5] = 1},{[1] = 11,[2] = 3,[3] = 1,[5] = 1}},
		[30592] = {{[1] = 1,[2] = 1,[3] = 1,[5] = 1},{[1] = 1,[2] = 2,[3] = 1,[5] = 1},{[1] = 1,[2] = 3,[3] = 1,[5] = 1}},
		[30593] = {{[1] = 1,[2] = 1,[3] = 1,[5] = 1},{[1] = 1,[2] = 2,[3] = 1,[5] = 1},{[1] = 1,[2] = 3,[3] = 1,[5] = 1}},
		[30594] = {{[1] = 1,[2] = 1,[3] = 1,[5] = 1},{[1] = 1,[2] = 2,[3] = 1,[5] = 1},{[1] = 1,[2] = 3,[3] = 1,[5] = 1}},
		[30600] = {{[1] = 2,[2] = 1,[3] = 1,[5] = 1},{[1] = 2,[2] = 2,[3] = 1,[5] = 1},{[1] = 2,[2] = 3,[3] = 1,[5] = 1}},
		[30601] = {{[1] = 2,[2] = 1,[3] = 1,[5] = 1},{[1] = 2,[2] = 2,[3] = 1,[5] = 1},{[1] = 2,[2] = 3,[3] = 1,[5] = 1}},
		[30602] = {{[1] = 2,[2] = 1,[3] = 1,[5] = 1},{[1] = 2,[2] = 2,[3] = 1,[5] = 1},{[1] = 2,[2] = 3,[3] = 1,[5] = 1}},
		[30603] = {{[1] = 8,[2] = 1,[3] = 1,[5] = 1},{[1] = 8,[2] = 2,[3] = 1,[5] = 1},{[1] = 8,[2] = 3,[3] = 1,[5] = 1}},
		[30604] = {{[1] = 8,[2] = 1,[3] = 1,[5] = 1},{[1] = 8,[2] = 2,[3] = 1,[5] = 1},{[1] = 8,[2] = 3,[3] = 1,[5] = 1}},
		[30605] = {{[1] = 8,[2] = 1,[3] = 1,[5] = 1},{[1] = 8,[2] = 2,[3] = 1,[5] = 1},{[1] = 8,[2] = 3,[3] = 1,[5] = 1}},
		[30606] = {{[1] = 9,[2] = 1,[3] = 1,[5] = 1},{[1] = 9,[2] = 2,[3] = 1,[5] = 1},{[1] = 9,[2] = 3,[3] = 1,[5] = 1},{[1] = 9,[2] = 4,[3] = 1,[5] = 1}},
		[30607] = {{[1] = 9,[2] = 1,[3] = 1,[5] = 1},{[1] = 9,[2] = 2,[3] = 1,[5] = 1},{[1] = 9,[2] = 3,[3] = 1,[5] = 1},{[1] = 9,[2] = 4,[3] = 1,[5] = 1}},
		[30608] = {{[1] = 9,[2] = 1,[3] = 1,[5] = 1},{[1] = 9,[2] = 2,[3] = 1,[5] = 1},{[1] = 9,[2] = 3,[3] = 1,[5] = 1},{[1] = 9,[2] = 4,[3] = 1,[5] = 1}},
		[30619] = {23,2,1},
		[30620] = {22,7,1},
		[30621] = {22,6,1},
		[30626] = {22,4,1},
		[30627] = {22,3,1},
		[30629] = {22,1,1},
		[30641] = {17,17,1},
		[30642] = {17,17,1},
		[30643] = {17,17,1},
		[30644] = {17,17,1},
		[30663] = {22,4,1},
		[30664] = {22,1,1},
		[30665] = {22,2,1},
		[30666] = {17,17,1},
		[30667] = {17,17,1},
		[30668] = {17,17,1},
		[30673] = {17,17,1},
		[30674] = {17,17,1},
		[30675] = {17,4,1},
		[30676] = {17,4,1},
		[30677] = {17,4,1},
		[30678] = {17,4,1},
		[30680] = {17,3,1},
		[30681] = {17,3,1},
		[30682] = {17,3,1},
		[30683] = {17,3,1},
		[30684] = {17,2,1},
		[30685] = {17,2,1},
		[30686] = {17,2,1},
		[30687] = {17,2,1},
		[30705] = {[1] = 3,[2] = 2,[3] = 1,[5] = 1},
		[30707] = {[1] = 3,[2] = 2,[3] = 1,[5] = 1},
		[30708] = {[1] = 3,[2] = 2,[3] = 1,[5] = 1},
		[30709] = {[1] = 3,[2] = 2,[3] = 1,[5] = 1},
		[30710] = {[1] = 3,[2] = 2,[3] = 1,[5] = 1},
		[30720] = {22,5,1},
		[30722] = {19,1,1},
		[30723] = {19,1,1},
		[30724] = {19,1,1},
		[30725] = {19,1,1},
		[30726] = {19,1,1},
		[30727] = {19,1,1},
		[30728] = {19,1,1},
		[30729] = {19,1,1},
		[30730] = {19,1,1},
		[30731] = {19,1,1},
		[30732] = {19,2,1},
		[30733] = {19,2,1},
		[30734] = {19,2,1},
		[30735] = {19,2,1},
		[30736] = {19,2,1},
		[30737] = {19,2,1},
		[30738] = {19,2,1},
		[30739] = {19,2,1},
		[30740] = {19,2,1},
		[30741] = {19,2,1},
		[30804] = {[3] = 17,[4] = 37818},
		[30808] = {7,2,1},
		[30816] = {[3] = 9,[4] = 37836},
		[30824] = {15,7,1},
		[30825] = {[3] = 17,[4] = 37855},
		[30827] = {7,3,1},
		[30828] = {10,1,1},
		[30829] = {3,3,1},
		[30831] = {[3] = 11,[4] = 37873},
		[30837] = {[3] = 11,[4] = 37882},
		[30838] = {[3] = 11,[4] = 37883},
		[30839] = {[3] = 11,[4] = 37884},
		[30861] = {24,1,1},
		[30862] = {24,1,1},
		[30863] = {24,1,1},
		[30864] = {24,1,1},
		[30865] = {24,1,1},
		[30866] = {24,1,1},
		[30868] = {24,1,1},
		[30869] = {24,1,1},
		[30870] = {24,1,1},
		[30871] = {24,1,1},
		[30872] = {24,1,1},
		[30873] = {24,1,1},
		[30874] = {24,2,1},
		[30878] = {24,2,1},
		[30879] = {24,2,1},
		[30880] = {24,2,1},
		[30881] = {24,2,1},
		[30882] = {24,2,1},
		[30883] = {24,2,1},
		[30884] = {24,2,1},
		[30885] = {24,2,1},
		[30886] = {24,2,1},
		[30887] = {24,2,1},
		[30888] = {24,2,1},
		[30889] = {24,3,1},
		[30891] = {24,3,1},
		[30892] = {24,3,1},
		[30893] = {24,3,1},
		[30894] = {24,3,1},
		[30895] = {24,3,1},
		[30896] = {24,4,1},
		[30897] = {24,4,1},
		[30898] = {24,4,1},
		[30899] = {24,4,1},
		[30900] = {24,4,1},
		[30901] = {24,4,1},
		[30902] = {24,5,1},
		[30903] = {24,5,1},
		[30904] = {24,5,1},
		[30905] = {24,5,1},
		[30906] = {24,5,1},
		[30907] = {24,5,1},
		[30908] = {24,5,1},
		[30909] = {24,5,1},
		[30910] = {24,5,1},
		[30911] = {24,5,1},
		[30912] = {24,5,1},
		[30913] = {24,5,1},
		[30914] = {24,3,1},
		[30915] = {24,3,1},
		[30916] = {24,3,1},
		[30917] = {24,3,1},
		[30918] = {24,3,1},
		[30919] = {24,3,1},
		[30969] = 31094,
		[30970] = 31094,
		[30972] = 31095,
		[30974] = 31095,
		[30975] = 31091,
		[30976] = 31091,
		[30977] = 31100,
		[30978] = 31100,
		[30979] = 31103,
		[30980] = 31103,
		[30982] = 31092,
		[30983] = 31092,
		[30985] = 31092,
		[30987] = 31097,
		[30988] = 31097,
		[30989] = 31097,
		[30990] = 31089,
		[30991] = 31089,
		[30992] = 31089,
		[30993] = 31098,
		[30994] = 31098,
		[30995] = 31098,
		[30996] = 31101,
		[30997] = 31101,
		[30998] = 31101,
		[31001] = 31094,
		[31003] = 31095,
		[31004] = 31091,
		[31005] = 31100,
		[31006] = 31103,
		[31007] = 31094,
		[31008] = 31094,
		[31011] = 31094,
		[31012] = 31095,
		[31014] = 31095,
		[31015] = 31095,
		[31016] = 31091,
		[31017] = 31091,
		[31018] = 31091,
		[31019] = 31100,
		[31020] = 31100,
		[31021] = 31100,
		[31022] = 31103,
		[31023] = 31103,
		[31024] = 31103,
		[31026] = 31093,
		[31027] = 31096,
		[31028] = 31090,
		[31029] = 31099,
		[31030] = 31102,
		[31032] = 31093,
		[31034] = 31093,
		[31035] = 31093,
		[31037] = 31096,
		[31039] = 31096,
		[31040] = 31096,
		[31041] = 31090,
		[31042] = 31090,
		[31043] = 31090,
		[31044] = 31099,
		[31045] = 31099,
		[31046] = 31099,
		[31047] = 31102,
		[31048] = 31102,
		[31049] = 31102,
		[31050] = 31092,
		[31051] = 31097,
		[31052] = 31089,
		[31053] = 31098,
		[31054] = 31101,
		[31055] = 31093,
		[31056] = 31096,
		[31057] = 31090,
		[31058] = 31099,
		[31059] = 31102,
		[31060] = 31092,
		[31061] = 31092,
		[31063] = 31097,
		[31064] = 31097,
		[31065] = 31089,
		[31066] = 31089,
		[31067] = 31098,
		[31068] = 31098,
		[31069] = 31101,
		[31070] = 31101,
		[31079] = {[3] = 17,[4] = 38068},
		[31080] = {[3] = 7,[4] = 38070},
		[31085] = {14,5,1},
		[31086] = {15,3,1},
		[31089] = {25,9,1},
		[31090] = {25,9,1},
		[31091] = {25,9,1},
		[31092] = {24,4,1},
		[31093] = {24,4,1},
		[31094] = {24,4,1},
		[31095] = {24,5,1},
		[31096] = {24,5,1},
		[31097] = {24,5,1},
		[31098] = {25,8,1},
		[31099] = {25,8,1},
		[31100] = {25,8,1},
		[31101] = {25,7,1},
		[31102] = {25,7,1},
		[31103] = {25,7,1},
		[31154] = {[3] = 17,[4] = 38175},
		[31364] = {[3] = 5,[4] = 38473},
		[31367] = {[3] = 5,[4] = 38475},
		[31368] = {[3] = 5,[4] = 38476},
		[31369] = {[3] = 5,[4] = 38477},
		[31370] = {[3] = 5,[4] = 38478},
		[31371] = {[3] = 5,[4] = 38479},
		[31398] = {[3] = 17,[4] = 38503},
		[31399] = {[3] = 17,[4] = 38504},
		[31554] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31562] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31570] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31578] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31672] = {[3] = 9,[4] = 38867},
		[31673] = {[3] = 9,[4] = 38868},
		[31676] = {[3] = 7,[4] = 38962},
		[31677] = {[3] = 7,[4] = 38961},
		[31679] = {[3] = 7,[4] = 38960},
		[31716] = {[1] = 3,[2] = 5,[3] = 1,[5] = 1},
		[31721] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[31722] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[31744] = {14,2,1},
		[31750] = {21,2,1},
		[31751] = {17,16,1},
		[31860] = {[3] = 17,[4] = 39451},
		[31861] = {[3] = 17,[4] = 39452},
		[31862] = {[3] = 17,[4] = 39455},
		[31863] = {[3] = 17,[4] = 39463},
		[31864] = {[3] = 17,[4] = 39458},
		[31865] = {[3] = 17,[4] = 39462},
		[31866] = {[3] = 17,[4] = 39466},
		[31867] = {[3] = 17,[4] = 39470},
		[31868] = {[3] = 17,[4] = 39471},
		[31869] = {[3] = 17,[4] = 39467},
		[31919] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31920] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31921] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31922] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31923] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[31924] = {[1] = 4,[2] = 4,[3] = 1,[5] = 1},
		[32062] = {[3] = 7,[4] = 39636},
		[32063] = {[3] = 7,[4] = 39637},
		[32067] = {[3] = 7,[4] = 39638},
		[32068] = {[3] = 7,[4] = 39639},
		[32072] = {[1] = 14,[2] = 5,[3] = 1,[5] = 1},
		[32073] = {[1] = 6,[2] = 2,[3] = 1,[5] = 1},
		[32076] = {[1] = 15,[2] = 3,[3] = 1,[5] = 1},
		[32077] = {[1] = 1,[2] = 3,[3] = 1,[5] = 1},
		[32078] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[32080] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[32081] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[32082] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[32193] = {[3] = 17,[4] = 39705},
		[32194] = {[3] = 17,[4] = 39706},
		[32195] = {[3] = 17,[4] = 39710},
		[32196] = {[3] = 17,[4] = 39711},
		[32197] = {[3] = 17,[4] = 39712},
		[32198] = {[3] = 17,[4] = 39713},
		[32199] = {[3] = 17,[4] = 39714},
		[32200] = {[3] = 17,[4] = 39715},
		[32201] = {[3] = 17,[4] = 39716},
		[32202] = {[3] = 17,[4] = 39717},
		[32203] = {[3] = 17,[4] = 39718},
		[32204] = {[3] = 17,[4] = 39719},
		[32205] = {[3] = 17,[4] = 39720},
		[32206] = {[3] = 17,[4] = 39721},
		[32207] = {[3] = 17,[4] = 39722},
		[32208] = {[3] = 17,[4] = 39723},
		[32209] = {[3] = 17,[4] = 39724},
		[32210] = {[3] = 17,[4] = 39725},
		[32211] = {[3] = 17,[4] = 39727},
		[32212] = {[3] = 17,[4] = 39728},
		[32213] = {[3] = 17,[4] = 39729},
		[32214] = {[3] = 17,[4] = 39730},
		[32215] = {[3] = 17,[4] = 39731},
		[32216] = {[3] = 17,[4] = 39732},
		[32217] = {[3] = 17,[4] = 39733},
		[32218] = {[3] = 17,[4] = 39734},
		[32219] = {[3] = 17,[4] = 39735},
		[32220] = {[3] = 17,[4] = 39736},
		[32221] = {[3] = 17,[4] = 39737},
		[32222] = {[3] = 17,[4] = 39738},
		[32223] = {[3] = 17,[4] = 39739},
		[32224] = {[3] = 17,[4] = 39740},
		[32225] = {[3] = 17,[4] = 39741},
		[32226] = {[3] = 17,[4] = 39742},
		[32227] = {{25,10,1},{26,8,1}},
		[32228] = {{25,10,1},{26,8,1}},
		[32229] = {{25,10,1},{26,8,1}},
		[32230] = {{25,10,1},{26,8,1}},
		[32231] = {{25,10,1},{26,8,1}},
		[32232] = {25,1,1},
		[32234] = {25,1,1},
		[32235] = {25,9,1},
		[32236] = {25,1,1},
		[32237] = {25,1,1},
		[32238] = {25,1,1},
		[32239] = {25,1,1},
		[32240] = {25,1,1},
		[32241] = {25,1,1},
		[32242] = {25,1,1},
		[32243] = {25,1,1},
		[32245] = {25,1,1},
		[32247] = {25,1,1},
		[32248] = {25,1,1},
		[32249] = {{25,10,1},{26,8,1}},
		[32250] = {25,2,1},
		[32251] = {25,2,1},
		[32252] = {25,2,1},
		[32253] = {25,2,1},
		[32254] = {25,2,1},
		[32255] = {25,2,1},
		[32256] = {25,2,1},
		[32257] = {25,2,1},
		[32258] = {25,2,1},
		[32259] = {25,2,1},
		[32260] = {25,2,1},
		[32261] = {25,2,1},
		[32262] = {25,2,1},
		[32263] = {25,3,1},
		[32264] = {25,3,1},
		[32265] = {25,3,1},
		[32266] = {25,3,1},
		[32267] = {23,3,1},
		[32268] = {25,3,1},
		[32269] = {25,4,1},
		[32270] = {25,3,1},
		[32271] = {25,3,1},
		[32273] = {25,3,1},
		[32275] = {25,3,1},
		[32276] = {25,3,1},
		[32278] = {25,3,1},
		[32279] = {25,3,1},
		[32280] = {25,6,1},
		[32285] = {24,6,1},
		[32289] = {24,6,1},
		[32295] = {24,6,1},
		[32296] = {24,6,1},
		[32297] = {24,6,1},
		[32298] = {24,6,1},
		[32303] = {24,6,1},
		[32307] = {24,6,1},
		[32323] = {25,6,1},
		[32324] = {25,6,1},
		[32325] = {25,6,1},
		[32326] = {25,6,1},
		[32327] = {25,6,1},
		[32328] = {25,6,1},
		[32329] = {25,6,1},
		[32330] = {25,6,1},
		[32331] = {25,8,1},
		[32332] = {25,5,1},
		[32333] = {25,4,1},
		[32334] = {25,4,1},
		[32335] = {25,4,1},
		[32336] = {25,9,1},
		[32337] = {25,4,1},
		[32338] = {25,4,1},
		[32339] = {25,4,1},
		[32340] = {25,4,1},
		[32341] = {25,4,1},
		[32342] = {25,4,1},
		[32343] = {25,4,1},
		[32344] = {25,4,1},
		[32345] = {25,5,1},
		[32346] = {25,5,1},
		[32347] = {25,5,1},
		[32348] = {25,6,1},
		[32349] = {25,5,1},
		[32350] = {25,5,1},
		[32351] = {25,5,1},
		[32352] = {25,5,1},
		[32353] = {25,5,1},
		[32354] = {25,5,1},
		[32361] = {25,3,1},
		[32362] = {25,5,1},
		[32363] = {25,5,1},
		[32365] = {25,7,1},
		[32366] = {25,7,1},
		[32367] = {25,7,1},
		[32368] = {25,7,1},
		[32369] = {25,7,1},
		[32370] = {25,7,1},
		[32373] = {25,8,1},
		[32374] = {25,9,1},
		[32375] = {25,9,1},
		[32376] = {25,8,1},
		[32377] = {25,1,1},
		[32385] = {20,1,1},
		[32389] = {[3] = 11,[4] = 40023},
		[32390] = {[3] = 11,[4] = 40024},
		[32391] = {[3] = 11,[4] = 40020},
		[32392] = {[3] = 11,[4] = 40021},
		[32393] = {[3] = 6,[4] = 40006},
		[32394] = {[3] = 6,[4] = 40003},
		[32395] = {[3] = 6,[4] = 40004},
		[32396] = {[3] = 6,[4] = 40005},
		[32397] = {[3] = 6,[4] = 40002},
		[32398] = {[3] = 6,[4] = 39997},
		[32399] = {[3] = 6,[4] = 40000},
		[32400] = {[3] = 6,[4] = 40001},
		[32401] = {[3] = 5,[4] = 40036},
		[32402] = {[3] = 5,[4] = 40033},
		[32403] = {[3] = 5,[4] = 40034},
		[32404] = {[3] = 5,[4] = 40035},
		[32405] = {23,4,1},
		[32409] = {[3] = 17,[4] = 39961},
		[32410] = {[3] = 17,[4] = 39963},
		[32413] = {[3] = 12,[4] = 39973},
		[32420] = {[3] = 11,[4] = 40060},
		[32423] = {[3] = 12,[4] = 39971},
		[32428] = {{24,6,1},{25,10,1}},
		[32458] = {23,4,1},
		[32459] = {24,1,1},
		[32461] = {[3] = 12,[4] = 40274},
		[32471] = {25,9,1},
		[32472] = {[3] = 12,[4] = 41311},
		[32473] = {[3] = 12,[4] = 41312},
		[32474] = {[3] = 12,[4] = 41314},
		[32475] = {[3] = 12,[4] = 41316},
		[32476] = {[3] = 12,[4] = 41315},
		[32478] = {[3] = 12,[4] = 41317},
		[32479] = {[3] = 12,[4] = 41318},
		[32480] = {[3] = 12,[4] = 41319},
		[32483] = {25,9,1},
		[32494] = {[3] = 12,[4] = 41320},
		[32495] = {[3] = 12,[4] = 41321},
		[32496] = {25,9,1},
		[32497] = {25,9,1},
		[32500] = {25,9,1},
		[32501] = {25,4,1},
		[32505] = {25,8,1},
		[32508] = {[3] = 17,[4] = 40514},
		[32510] = {25,6,1},
		[32512] = {25,6,1},
		[32513] = {25,3,1},
		[32515] = {23,2,1},
		[32516] = {22,1,1},
		[32517] = {25,5,1},
		[32518] = {25,8,1},
		[32519] = {25,8,1},
		[32521] = {25,9,1},
		[32524] = {25,9,1},
		[32525] = {25,9,1},
		[32526] = {25,10,1},
		[32527] = {25,10,1},
		[32528] = {25,10,1},
		[32568] = {[3] = 5,[4] = 41132},
		[32570] = {[3] = 5,[4] = 41133},
		[32571] = {[3] = 5,[4] = 41134},
		[32573] = {[3] = 5,[4] = 41135},
		[32574] = {[3] = 6,[4] = 41161},
		[32575] = {[3] = 6,[4] = 41162},
		[32577] = {[3] = 6,[4] = 41163},
		[32579] = {[3] = 6,[4] = 41164},
		[32580] = {[3] = 6,[4] = 41158},
		[32581] = {[3] = 6,[4] = 41160},
		[32582] = {[3] = 6,[4] = 41156},
		[32583] = {[3] = 6,[4] = 41157},
		[32584] = {[3] = 11,[4] = 41207},
		[32585] = {[3] = 11,[4] = 41208},
		[32586] = {[3] = 11,[4] = 41205},
		[32587] = {[3] = 11,[4] = 41206},
		[32589] = {{24,6,1},{25,10,1}},
		[32590] = {{24,6,1},{25,10,1}},
		[32591] = {{24,6,1},{25,10,1}},
		[32592] = {{24,6,1},{25,10,1}},
		[32593] = {25,10,1},
		[32606] = {25,10,1},
		[32608] = {25,10,1},
		[32609] = {{24,6,1},{25,10,1}},
		[32736] = {25,11,1},
		[32737] = {25,11,1},
		[32738] = {25,11,1},
		[32739] = {25,11,1},
		[32744] = {25,11,1},
		[32745] = {25,11,1},
		[32746] = {25,11,1},
		[32747] = {25,11,1},
		[32748] = {25,11,1},
		[32749] = {25,11,1},
		[32750] = {25,11,1},
		[32751] = {25,11,1},
		[32752] = {25,11,1},
		[32753] = {25,11,1},
		[32754] = {25,11,1},
		[32755] = {25,11,1},
		[32756] = {[3] = 12,[4] = 41307},
		[32768] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32769] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32772] = {[3] = 17,[4] = 41414},
		[32774] = {[3] = 17,[4] = 41415},
		[32776] = {[3] = 17,[4] = 41418},
		[32778] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32779] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32780] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32781] = {[1] = 6,[2] = 3,[3] = 1,[5] = 1},
		[32833] = {[3] = 17,[4] = 41420},
		[32836] = {[3] = 17,[4] = 41429},
		[32837] = {25,9,1},
		[32838] = {25,9,1},
		[32839] = {[3] = 7,[4] = 41458},
		[32849] = {[3] = 7,[4] = 41500},
		[32850] = {[3] = 7,[4] = 41501},
		[32851] = {[3] = 7,[4] = 41502},
		[32852] = {[3] = 7,[4] = 41503},
		[32854] = {[3] = 5,[4] = 43846},
		[32897] = {{22,7,1},{23,6,1},{24,6,1},{25,10,1}},
		[32943] = {25,10,1},
		[32944] = {23,1,1},
		[32945] = {24,6,1},
		[32946] = {24,6,1},
		[33048] = {[3] = 9,[4] = 42296},
		[33052] = {[3] = 9,[4] = 42302},
		[33053] = {[3] = 9,[4] = 42305},
		[33054] = {22,2,1},
		[33055] = {22,1,1},
		[33058] = {22,5,1},
		[33092] = {[3] = 12,[4] = 30551},
		[33093] = {[3] = 12,[4] = 30552},
		[33102] = {18,6,1},
		[33122] = {[3] = 6,[4] = 42546},
		[33131] = {[3] = 17,[4] = 42589},
		[33133] = {[3] = 17,[4] = 42558},
		[33134] = {[3] = 17,[4] = 42588},
		[33135] = {[3] = 17,[4] = 42590},
		[33140] = {[3] = 17,[4] = 42592},
		[33143] = {[3] = 17,[4] = 42591},
		[33144] = {[3] = 17,[4] = 42593},
		[33173] = {[3] = 5,[4] = 42662},
		[33185] = {[3] = 5,[4] = 42688},
		[33191] = {18,2,1},
		[33203] = {18,2,1},
		[33204] = {[3] = 6,[4] = 42731},
		[33206] = {18,2,1},
		[33208] = {[3] = 7,[4] = 42736},
		[33211] = {18,2,1},
		[33214] = {18,1,1},
		[33215] = {18,1,1},
		[33216] = {18,1,1},
		[33281] = {18,1,1},
		[33283] = {18,1,1},
		[33285] = {18,2,1},
		[33286] = {18,1,1},
		[33293] = {18,1,1},
		[33297] = {18,4,1},
		[33298] = {18,5,1},
		[33299] = {18,4,1},
		[33300] = {18,4,1},
		[33303] = {18,4,1},
		[33307] = {[1] = 18,[3] = 1},
		[33317] = {18,4,1},
		[33322] = {18,4,1},
		[33326] = {18,3,1},
		[33327] = {18,2,1},
		[33328] = {18,3,1},
		[33329] = {18,3,1},
		[33332] = {18,3,1},
		[33354] = {18,3,1},
		[33356] = {18,3,1},
		[33357] = {18,3,1},
		[33388] = {18,5,1},
		[33389] = {18,5,1},
		[33421] = {18,5,1},
		[33432] = {18,5,1},
		[33446] = {18,5,1},
		[33453] = {18,5,1},
		[33463] = {18,5,1},
		[33464] = {18,5,1},
		[33465] = {18,5,1},
		[33466] = {18,6,1},
		[33467] = {18,6,1},
		[33468] = {18,6,1},
		[33469] = {18,6,1},
		[33471] = {18,6,1},
		[33473] = {18,6,1},
		[33474] = {18,6,1},
		[33476] = {18,6,1},
		[33478] = {18,6,1},
		[33479] = {18,6,1},
		[33480] = {18,7,1},
		[33481] = {18,7,1},
		[33483] = {18,7,1},
		[33489] = {18,7,1},
		[33490] = {18,7,1},
		[33491] = {18,7,1},
		[33492] = {18,7,1},
		[33493] = {18,7,1},
		[33494] = {18,7,1},
		[33495] = {18,7,1},
		[33496] = {18,7,1},
		[33497] = {18,7,1},
		[33498] = {18,7,1},
		[33499] = {18,7,1},
		[33500] = {18,7,1},
		[33533] = {18,4,1},
		[33590] = {18,7,1},
		[33591] = {18,7,1},
		[33592] = {18,5,1},
		[33640] = {18,2,1},
		[33782] = {[3] = 17,[4] = 43493},
		[33791] = {[3] = 5,[4] = 43549},
		[33805] = {18,7,1},
		[33809] = {18,7,1},
		[33814] = {[1] = 2,[2] = 3,[3] = 1,[5] = 1},
		[33815] = {[1] = 3,[2] = 4,[3] = 1,[5] = 1},
		[33821] = {[1] = 8,[2] = 3,[3] = 1,[5] = 1},
		[33825] = {[3] = 9,[4] = 43707},
		[33826] = {[1] = 9,[2] = 4,[3] = 1,[5] = 1},
		[33827] = {[1] = 10,[2] = 3,[3] = 1,[5] = 1},
		[33828] = {18,5,1},
		[33829] = {18,5,1},
		[33830] = {18,6,1},
		[33831] = {18,6,1},
		[33834] = {[1] = 6,[2] = 2,[3] = 1,[5] = 1},
		[33835] = {[1] = 4,[2] = 3,[3] = 1,[5] = 1},
		[33836] = {[1] = 5,[2] = 2,[3] = 1,[5] = 1},
		[33839] = {[3] = 9,[4] = 43718},
		[33840] = {[1] = 7,[2] = 4,[3] = 1,[5] = 1},
		[33847] = {[1] = 11,[2] = 3,[3] = 1,[5] = 1},
		[33850] = {[3] = 9,[4] = 43724},
		[33858] = {[1] = 12,[2] = 3,[3] = 1,[5] = 1},
		[33859] = {[1] = 14,[2] = 5,[3] = 1,[5] = 1},
		[33860] = {[1] = 15,[2] = 3,[3] = 1,[5] = 1},
		[33861] = {[1] = 13,[2] = 4,[3] = 1,[5] = 1},
		[33865] = {18,8,1},
		[33866] = {[3] = 9,[4] = 43758},
		[33867] = {[3] = 9,[4] = 43761},
		[33872] = {[3] = 9,[4] = 43765},
		[33874] = {[3] = 9,[4] = 43772},
		[33924] = {[3] = 9,[4] = 43779},
		[33930] = {18,8,1},
		[33931] = {18,8,1},
		[33932] = {18,8,1},
		[33933] = {18,8,1},
		[33971] = {18,7,1},
		[33993] = {18,8,1},
		[34009] = {{24,6,1},{25,10,1}},
		[34010] = {24,6,1},
		[34011] = {25,10,1},
		[34012] = {25,10,1},
		[34029] = {18,5,1},
		[34060] = {[3] = 12,[4] = 44155},
		[34061] = {[3] = 12,[4] = 44157},
		[34085] = {[3] = 11,[4] = 44958},
		[34086] = {[3] = 6,[4] = 44953},
		[34087] = {[3] = 11,[4] = 44950},
		[34099] = {[3] = 6,[4] = 44343},
		[34100] = {[3] = 6,[4] = 44344},
		[34105] = {[3] = 6,[4] = 44359},
		[34106] = {[3] = 6,[4] = 44768},
		[34113] = {[3] = 12,[4] = 44391},
		[34157] = {16,4,1},
		[34164] = {26,1,1},
		[34165] = {26,1,1},
		[34166] = {26,1,1},
		[34167] = {26,1,1},
		[34168] = {26,1,1},
		[34169] = {26,1,1},
		[34170] = {26,1,1},
		[34176] = {26,2,1},
		[34177] = {26,2,1},
		[34178] = {26,2,1},
		[34179] = {26,2,1},
		[34180] = {26,2,1},
		[34181] = {26,2,1},
		[34182] = {26,3,1},
		[34183] = {26,8,1},
		[34184] = {26,3,1},
		[34185] = {26,3,1},
		[34186] = {26,3,1},
		[34188] = {26,3,1},
		[34189] = {26,4,1},
		[34190] = {26,4,1},
		[34192] = {26,4,1},
		[34193] = {26,4,1},
		[34194] = {26,4,1},
		[34195] = {26,4,1},
		[34196] = {26,4,1},
		[34197] = {26,4,1},
		[34198] = {26,4,1},
		[34199] = {26,4,1},
		[34202] = {26,4,1},
		[34203] = {26,4,1},
		[34204] = {26,4,1},
		[34205] = {26,4,1},
		[34206] = {26,4,1},
		[34207] = {[3] = 6,[4] = 44770},
		[34208] = {26,4,1},
		[34209] = {26,4,1},
		[34210] = {26,4,1},
		[34211] = {26,5,1},
		[34212] = {26,5,1},
		[34213] = {26,5,1},
		[34214] = {26,5,1},
		[34215] = {26,5,1},
		[34216] = {26,5,1},
		[34220] = {[3] = 17,[4] = 44794},
		[34228] = {26,5,1},
		[34229] = {26,5,1},
		[34230] = {26,5,1},
		[34231] = {26,5,1},
		[34232] = {26,5,1},
		[34233] = {26,5,1},
		[34234] = {26,5,1},
		[34240] = {26,5,1},
		[34241] = {26,6,1},
		[34242] = {26,6,1},
		[34243] = {26,6,1},
		[34244] = {26,6,1},
		[34245] = {26,6,1},
		[34247] = {26,6,1},
		[34329] = {26,6,1},
		[34330] = {[3] = 6,[4] = 44970},
		[34331] = {26,6,1},
		[34332] = {26,6,1},
		[34333] = {26,6,1},
		[34334] = {26,6,1},
		[34335] = {26,6,1},
		[34336] = {26,6,1},
		[34337] = {26,6,1},
		[34339] = {26,6,1},
		[34340] = {26,6,1},
		[34341] = {26,6,1},
		[34342] = {26,6,1},
		[34343] = {26,6,1},
		[34344] = {26,6,1},
		[34345] = {26,6,1},
		[34346] = {26,8,1},
		[34347] = {26,8,1},
		[34348] = {26,8,1},
		[34349] = {26,8,1},
		[34350] = {26,8,1},
		[34351] = {26,8,1},
		[34352] = {26,3,1},
		[34353] = {[3] = 12,[4] = 46116},
		[34354] = {[3] = 12,[4] = 46114},
		[34355] = {[3] = 12,[4] = 46112},
		[34356] = {[3] = 12,[4] = 46113},
		[34357] = {[3] = 12,[4] = 46115},
		[34358] = {[3] = 17,[4] = 46127},
		[34359] = {[3] = 17,[4] = 46125},
		[34360] = {[3] = 17,[4] = 46126},
		[34361] = {[3] = 17,[4] = 46124},
		[34362] = {[3] = 17,[4] = 46122},
		[34363] = {[3] = 17,[4] = 46123},
		[34364] = {[3] = 11,[4] = 46130},
		[34365] = {[3] = 11,[4] = 46131},
		[34366] = {[3] = 11,[4] = 46128},
		[34367] = {[3] = 11,[4] = 46129},
		[34369] = {[3] = 6,[4] = 46138},
		[34370] = {[3] = 6,[4] = 46134},
		[34371] = {[3] = 6,[4] = 46136},
		[34372] = {[3] = 6,[4] = 46132},
		[34373] = {[3] = 6,[4] = 46137},
		[34374] = {[3] = 6,[4] = 46133},
		[34375] = {[3] = 6,[4] = 46139},
		[34376] = {[3] = 6,[4] = 46135},
		[34377] = {[3] = 5,[4] = 46144},
		[34378] = {[3] = 5,[4] = 46141},
		[34379] = {[3] = 5,[4] = 46142},
		[34380] = {[3] = 5,[4] = 46140},
		[34381] = {26,2,1},
		[34382] = {26,1,1},
		[34383] = {26,3,1},
		[34384] = {26,1,1},
		[34385] = {26,3,1},
		[34386] = {26,1,1},
		[34388] = {26,4,1},
		[34389] = {26,4,1},
		[34390] = {26,4,1},
		[34391] = {26,4,1},
		[34392] = {26,4,1},
		[34393] = {26,4,1},
		[34394] = {26,5,1},
		[34395] = {26,5,1},
		[34396] = {26,5,1},
		[34397] = {26,5,1},
		[34398] = {26,5,1},
		[34399] = {26,5,1},
		[34400] = {26,6,1},
		[34401] = {26,6,1},
		[34402] = {26,6,1},
		[34403] = {26,6,1},
		[34404] = {26,6,1},
		[34405] = {26,6,1},
		[34406] = {26,6,1},
		[34407] = {26,8,1},
		[34408] = {26,5,1},
		[34409] = {26,8,1},
		[34411] = {[3] = 9,[4] = 45022},
		[34427] = {26,5,1},
		[34428] = {26,5,1},
		[34429] = {26,5,1},
		[34430] = {26,5,1},
		[34431] = 34848,
		[34432] = 34848,
		[34433] = 34848,
		[34434] = 34848,
		[34435] = 34848,
		[34436] = 34848,
		[34437] = 34851,
		[34438] = 34851,
		[34439] = 34851,
		[34440] = {[3] = 7,[4] = 45061},
		[34441] = 34851,
		[34442] = 34851,
		[34443] = 34851,
		[34444] = 34852,
		[34445] = 34852,
		[34446] = 34852,
		[34447] = 34852,
		[34448] = 34852,
		[34470] = {[1] = 16,[2] = 3,[3] = 1,[5] = 1},
		[34471] = {[1] = 16,[2] = 3,[3] = 1,[5] = 1},
		[34472] = {[1] = 16,[2] = 3,[3] = 1,[5] = 1},
		[34473] = {[1] = 16,[2] = 3,[3] = 1,[5] = 1},
		[34482] = {[3] = 6,[4] = 45100},
		[34485] = 34853,
		[34487] = 34853,
		[34488] = 34853,
		[34490] = {[3] = 6,[4] = 45117},
		[34504] = {[3] = 12,[4] = 30347},
		[34527] = 34853,
		[34528] = 34853,
		[34541] = 34853,
		[34542] = 34854,
		[34543] = 34854,
		[34545] = 34854,
		[34546] = 34854,
		[34547] = 34854,
		[34549] = 34854,
		[34554] = 34855,
		[34555] = 34855,
		[34556] = 34855,
		[34557] = 34855,
		[34558] = 34855,
		[34559] = 34856,
		[34560] = 34856,
		[34561] = 34856,
		[34562] = 34856,
		[34563] = 34856,
		[34564] = 34856,
		[34565] = 34857,
		[34566] = 34857,
		[34567] = 34857,
		[34568] = 34857,
		[34569] = 34857,
		[34570] = 34857,
		[34571] = 34858,
		[34572] = 34858,
		[34573] = 34858,
		[34574] = 34858,
		[34575] = 34858,
		[34601] = {[1] = 16,[2] = 1,[3] = 1,[5] = 1},
		[34602] = {[1] = 16,[2] = 1,[3] = 1,[5] = 1},
		[34603] = {[1] = 16,[2] = 1,[3] = 1,[5] = 1},
		[34604] = {[1] = 16,[2] = 1,[3] = 1,[5] = 1},
		[34605] = {[1] = 16,[2] = 2,[3] = 1,[5] = 1},
		[34606] = {[1] = 16,[2] = 2,[3] = 1,[5] = 1},
		[34607] = {[1] = 16,[2] = 2,[3] = 1,[5] = 1},
		[34608] = {[1] = 16,[2] = 2,[3] = 1,[5] = 1},
		[34609] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34610] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34611] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34612] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34613] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34614] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34615] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34616] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[34625] = {16,4,1},
		[34664] = {26,8,1},
		[34697] = {16,1,1},
		[34698] = {16,1,1},
		[34699] = {16,1,1},
		[34700] = {16,1,1},
		[34701] = {16,1,1},
		[34702] = {16,1,1},
		[34703] = {16,2,1},
		[34704] = {16,2,1},
		[34705] = {16,2,1},
		[34706] = {16,2,1},
		[34707] = {16,2,1},
		[34708] = {16,2,1},
		[34783] = {16,3,1},
		[34788] = {16,3,1},
		[34789] = {16,3,1},
		[34790] = {16,3,1},
		[34791] = {16,3,1},
		[34792] = {16,3,1},
		[34793] = {16,4,1},
		[34794] = {16,4,1},
		[34795] = {16,4,1},
		[34796] = {16,4,1},
		[34797] = {16,4,1},
		[34798] = {16,4,1},
		[34799] = {16,4,1},
		[34807] = {16,4,1},
		[34808] = {16,4,1},
		[34809] = {16,4,1},
		[34810] = {16,4,1},
		[34832] = {[3] = 9,[4] = 45695},
		[34845] = {20,1,1},
		[34846] = {20,1,1},
		[34847] = {[3] = 12,[4] = 46111},
		[34848] = {26,1,1},
		[34851] = {26,1,1},
		[34852] = {26,1,1},
		[34853] = {26,2,1},
		[34854] = {26,2,1},
		[34855] = {26,2,1},
		[34856] = {26,3,1},
		[34857] = {26,3,1},
		[34858] = {26,3,1},
		[34955] = {8,4,1},
		[35128] = {[3] = 10,[4] = 46353},
		[35181] = {[3] = 12,[4] = 46108},
		[35182] = {[3] = 12,[4] = 46109},
		[35183] = {[3] = 12,[4] = 46106},
		[35184] = {[3] = 12,[4] = 46110},
		[35185] = {[3] = 12,[4] = 46107},
		[35186] = {26,7,1},
		[35187] = {26,7,1},
		[35189] = {26,7,1},
		[35190] = {26,7,1},
		[35191] = {26,7,1},
		[35192] = {26,7,1},
		[35193] = {26,7,1},
		[35194] = {26,7,1},
		[35195] = {26,7,1},
		[35196] = {26,7,1},
		[35197] = {26,7,1},
		[35198] = {26,7,1},
		[35199] = {26,7,1},
		[35200] = {26,7,1},
		[35201] = {26,7,1},
		[35202] = {26,7,1},
		[35203] = {26,7,1},
		[35204] = {26,7,1},
		[35205] = {26,7,1},
		[35206] = {26,7,1},
		[35207] = {26,7,1},
		[35208] = {26,8,1},
		[35209] = {26,8,1},
		[35210] = {26,8,1},
		[35211] = {26,8,1},
		[35212] = {26,7,1},
		[35213] = {26,7,1},
		[35214] = {26,7,1},
		[35215] = {26,7,1},
		[35216] = {26,7,1},
		[35217] = {26,7,1},
		[35218] = {26,7,1},
		[35219] = {26,7,1},
		[35273] = {26,8,1},
		[35275] = {{[1] = 16,[2] = 1,[3] = 1,[5] = 1},{[1] = 16,[2] = 2,[3] = 1,[5] = 1},{[1] = 16,[2] = 3,[3] = 1,[5] = 1}},
		[35282] = {26,5,1},
		[35283] = {26,5,1},
		[35284] = {26,5,1},
		[35290] = {26,4,1},
		[35291] = {26,4,1},
		[35292] = {26,4,1},
		[35304] = {16,4,1},
		[35311] = {16,4,1},
		[35315] = {[3] = 17,[4] = 46403},
		[35316] = {[3] = 17,[4] = 46404},
		[35318] = {[3] = 17,[4] = 46405},
		[35494] = {8,4,1},
		[35495] = {8,4,1},
		[35496] = {8,4,1},
		[35497] = {8,4,1},
		[35498] = {8,4,1},
		[35501] = {[3] = 17,[4] = 46597},
		[35503] = {[3] = 17,[4] = 46601},
		[35504] = {16,4,1},
		[35507] = {[1] = 8,[2] = 4,[3] = 1,[5] = 1},
		[35508] = {[1] = 8,[2] = 4,[3] = 1,[5] = 1},
		[35509] = {[1] = 8,[2] = 4,[3] = 1,[5] = 1},
		[35511] = {[1] = 8,[2] = 4,[3] = 1,[5] = 1},
		[35513] = {[1] = 16,[2] = 4,[3] = 1,[5] = 1},
		[35514] = {8,4,1},
		[35516] = {16,5,1},
		[35557] = {8,4,1},
		[35563] = {[3] = 9,[4] = 46684},
		[35565] = {[3] = 9,[4] = 46688},
		[35581] = {[3] = 12,[4] = 46697},
		[35582] = {15,1,1},
		[35693] = {[3] = 17,[4] = 46775},
		[35694] = {[3] = 17,[4] = 46776},
		[35700] = {[3] = 17,[4] = 46777},
		[35702] = {[3] = 17,[4] = 46778},
		[35703] = {[3] = 17,[4] = 46779},
		[35707] = {[3] = 17,[4] = 46803},
		[35723] = {8,4,1},
		[35733] = {26,8,1},
		[35748] = {[3] = 7,[4] = 47046},
		[35749] = {[3] = 7,[4] = 47048},
		[35750] = {[3] = 7,[4] = 47049},
		[35751] = {[3] = 7,[4] = 47050},
		[35756] = {16,3,1},
		[35758] = {[3] = 17,[4] = 47054},
		[35759] = {[3] = 17,[4] = 47053},
		[35760] = {[3] = 17,[4] = 47055},
		[35761] = {[3] = 17,[4] = 47056},
		[35945] = {[3] = 17,[4] = 47280},
		[37503] = {[3] = 17,[4] = 48789},
		[38225] = {[3] = 11,[4] = 50194},
		[38276] = {11,4,1},
		[38277] = {[3] = 11,[4] = 50644},
		[38278] = {[3] = 11,[4] = 50647},
		[38329] = {11,4,1},
		[38506] = {[1] = 11,[2] = 4,[3] = 1,[5] = 1},
		[185848] = {[3] = 6,[4] = 351771},
		[185849] = {[3] = 6,[4] = 351770},
		[185851] = {[3] = 6,[4] = 351768},
		[185852] = {[3] = 6,[4] = 351766}
	}
}
--##END-DATA##
AtlasLoot.Addons:GetAddon("Sources"):SetData(SOURCE_DATA)
